unit okapi32;

{$mode objfpc}{$H+}

interface

uses
  Windows, Classes, SysUtils;

//==============================================================================
//
//       filename        okapi32.pas
//       purpose         API for dynamic loading okapi32.dll (Ok series image cards)
//       language        Lazarus 1.0.8
//       author          H. Peng
//       date            2013.4.26
//-----------------------
//       modify by       H. Peng
//       purpose         Add Three Function
//       language        Lazarus 1.0.8
//       date            2013.4
//
//-----------------------
//
//       Copyright (C).  All Rights Reserved.
//
//
//==============================================================================


//---------------okapi32.pas---------------------------------
//
// ok api32 header file for user
//
//---------------------------------------------------------

//----contant defines----

//--defines of ok series image board identity
//Mono series


//-----------struct defines---------------

//--app user used struct
type
//----data type defines ------------------------------------------------------------------------------------

//--datatype defines and bytes
//	signed			signed pointer		unsigned		unsigned pointer
//	CHAR (1)		LPSTR (4/8)		BYTE (1)		LPBYTE (4/8)
//	SHORT (2)		LPSHORT	((4/8)		WORD (2)		LPWORD (4/8)
//	INT32 (4)		LPINT32	(4/8)		DWORD (4)		LPDWORD (4/8)
//	LONG64 (8)		LPLONG64 (4/8)		QWORD (8)		LPQWORD (4/8)
//      MLONG (4/8)		LPMLONG (4/8)		MWORD (4/8)		LPMWORD (4/8)
//      VOID			HANDLE, HWND, LPVOID (4/8)
//	note: (4/8) mean: 4 bytes in 32bits OS, 8 in 64bits OS

//-----fixed size data define (exclude pointers)
//1 byte prototype: (unsigned) char, __int8
//typedef		char				CHAR,	*PCHAR, *LPSTR;
//typedef		unsigned char		        BYTE,	*PBYTE, *LPBYTE;

//2 byte prototype: (unsigned) short, __int16
//typedef		short				SHORT,	*PSHORT, *LPSHORT;
//typedef		unsigned short		        WORD,	*PWORD,	*LPWORD;

//4 byte prototype: (unsigned) long, int, __int32
//typedef		int				INT32,	*PINT32, *LPINT32;;
//typedef		unsigned long		        DWORD, *PDWORD, *LPDWORD;
//typedef		unsigned __int32	        DWORD; //

//typedef		float				FLOAT,	*PFLOAT, *LPFLOAT ; //float

//8 byte prototype:  __int64, long, int
//typedef		__int64				LONG64,	*PLONG64, *LPLONG64;
//typedef		unsigned __int64	        QWORD,	*PQWORD, *LPQWORD;

//typedef		double				DOUBLE, *PDOUBLE, *LPDOUBLE;   //float

//typedef		void				*HANDLE, *LPVOID;    //which are 4 bytes in 32 system, 8 bytes in 64 system
//typedef	        void				*HWND;    //which are 4 bytes in 32 system, 8 bytes in 64 system

//-----unfixed size data defines
//typedef		int				BOOL;	//32 or 64 not sure


//-----4 or 8 byte size depent on 32 or 64 OS
//#define		__64OS
//#ifndef		__64OS
//typedef		long				MLONG,	*PMLONG, *LPMLONG;	//which are 4 bytes in 32 system, 8 bytes in 64 system
    MLONG = Longint;
    MWORD = DWORD;
    INT32 = Integer;
//typedef		unsigned long	                MWORD,	*PMWORD, *LPMWORD;  //which are 4 bytes in 32 system, 8 bytes in 64 system
//#else
//typedef		long				MLONG,	*PMLONG, *LPMLONG;  //which are 4 bytes in 32 system, 8 bytes in 64 system
//typedef		unsigned __int64	        MWORD,	*PMWORD, *LPMWORD;  //which are 4 bytes in 32 system, 8 bytes in 64 system
//#endif
    LPBYTE = ^BYTE;

    _okdevtype = Record                                 //added after 28/02/2005, to replace struct _boardtype
	      iBoardTypeCode:Longint;                   //ok image device type code (e.g. 2030(capture card), 201100(camera))
	      iBoardIdentCode:Longint;                  //ok image device identity code (e.g. 2130), or ip value
	      iBoardRankCode:Longint;                   //ok image device model code 0,1,..
	      szBoardName:Array [0..23] of char;        //ok image device name (eg."OK_M20H", "OK_AM1100"...)
      	      szSubDrvName:Array[0..87] of char;        //ok sub-driver name(eg. "okc30.dll")
              dwSpecCaps:DWORD;                         //special capabilities flag. b0: audio, b1:stream encoder
    end;  //128 bytes

    _boardtype = Record
        iBoardTypeCode:Smallint;                        //ok board type code (e.g. 2030)
        szBoardName:Array [0..17] of char;              //board name (eg."OK_M20H")
	      iBoardIdentCode:Smallint;                 //ok board identity code (e.g. 2130)
        iBoardRankCode:Smallint;                        //ok board model code 0,1,..
    end;

    //image file block size
    _blocksize = Record
        iWidth:Smallint;		//width
        iHeight:Smallint;               //height
        iBitCount:Smallint;             //pixel bytes iBitCount
        iFormType:Smallint;             //rgb format type, need to fill when RGB565 or RGB 555
        lBlockStep:Longint;             //block stride (step to next image header)
  				        //need to fill when treat multi block else set 0
    end;

    //image block info
    _blockinfo = Record
        iType:Smallint;	                // =BK or SQ, BM
        //struct _blocksize;
        iWidth:Smallint;                // width
        iHeight:Smallint;               // height
        iBitCount:Smallint;             // pixel bytes iBitCount
        iFormType:Smallint;             // rgb format type, need to fill when RGB565 or RGB 555
        lBlockStep:Smallint;            // block stride (step to next image header)
        iHiStep:Smallint;               // HIWORD of block stride

        lTotal:Smallint;                // frame num
        iHiTotal:Smallint;              // HIWORD of total
        iInterval:Smallint;             // frame interval
        lpBits:^BYTE;                   // image data pointer / file path name
        lpExtra:^BYTE;                  // extra data (like as palette, mask) pointer
    end;

    //sequence file info
    SEQINFO = Record                        //file info for seq
	      iType:Smallint;               //=SQ or BM
	      //struct _blocksize;
	      iWidth:Smallint;              //width
	      iHeight:Smallint;             //height
	      iBitCount:Smallint;           //pixel bytes iBitCount
	      iFormType:Smallint;           //rgb format type, need to fill when RGB565 or RGB 555
	      lBlockStep:Smallint;          //block stride (step to next image header)
	      iHiStep:Smallint;             // HIWORD of block stride

	      lTotal:Smallint;              //frame num
	      iHiTotal:Smallint;            // HIWORD of total
	      iInterval:Smallint;           //frame interval
    end;


    //set raw file parameters
    _rawfileparam = Record
	      wRawFlag:WORD;  //raw file flag,  RAWFILE:0x5752
	      wPixBits:WORD;  //bits per pixel
	      dwWidth:DWORD;  //width
	      dwHeight:DWORD; //height
	      dwOffset:DWORD; //file header
	      reserved:DWORD; //res
    end;

    //for replay
    DIBINFO=Record                         //file info for seq
	lpbi:PBITMAPINFOHEADER;            //bitmap info
        lpdib:^BYTE;                       //dib data
        hwndPlayBox:HWND;                  //1 replaying, 0 quit
        iCurrFrame:Smallint;               //current frame in buffer
	iReserved:Smallint;                //
    end;

    //---set text mode----
    _settextmode = Record
	      dwForeColor:DWORD;  // forecolor, see macro RGB in win
	      dwBackColor:DWORD;  // backcolor, see macro RGB in win
	      dwSetMode:DWORD;    // 0:FULLCOPY, 1: FULLXOR, ...  0x100,0x200:
	      wFrameNo:WORD;      // place which frame of target
        wGroupNo:WORD;            //
    end;

    //---image size------
    _imagesize = Record
    	      dwWidth:DWORD;
    	      dwHeight:DWORD;
    	      dwBitCount:DWORD;
    	      dwTotal:DWORD;
    end;

    //--jpeg set params
    _jpegparam = Record
    	      dwSize:DWORD;           // the size of this strcut, must be set
    	      lpstrName:LPSTR;	      //must be NULL if not use
    	      dwQuality:DWORD;        //
    	      dwReserved1:DWORD;
    end;

    //----------
    _imagesize_info = Record
    	      lHeadSize:Longint;                     //struct header size
    	      lHorzSize:Longint;	             //width, (default=768 when it as input)
    	      lVertSize:Longint;	             //height, (default=768 when it as input)
    	      lBitCount:Longint;                     //bit count (default=24 when it as input)
    	      lTotalFrame:Longint;                   //total frames
    	      lQuality:Longint;                      //quality factor (for jpeg, default =75)
    	      bHardEncode:WORD;                      //flag of encode by harware
    	      wRes:WORD;
    	      res0:Array [0..4] of Longint;          //args reserved
    end;     //12X4

    //---used to set and get image info ------
    _jpg2k_header_info  = Record
    	      //struct _imagesize_info;
    	      lHeadSize:Longint;                     //struct header size
    	      lHorzSize:Longint;	             //width, (default=768 when it as input)
    	      lVertSize:Longint;	             //height, (default=768 when it as input)
    	      lBitCount:Longint;                     //bit count (default=24 when it as input)
    	      lTotalFrame:Longint;                   //total frames
    	      lQuality:Longint;                      //quality factor (for jpeg, default =75)
    	      bHardEncode:WORD;                      //flag of encode by harware
    	      wRes:WORD;
    	      res0:Array [0..4] of Longint;	     //args reserved
    	      //---end commnon--

    	      lpExtraInfo:Pointer;                   //reserved, to store extra infos
    	      res1:Array [0..16] of Longint;	     //args reserved
    end;



    //---used to set and get image info ------
    _mpg2_header_info = Record
    	      //struct _imagesize_info;
    	      lHeadSize:Longint;                     //struct header size
    	      lHorzSize:Longint;	             //width, (default=768 when it as input)
    	      lVertSize:Longint;	             //height, (default=768 when it as input)
    	      lBitCount:Longint;                     //bit count (default=24 when it as input)
    	      lTotalFrame:Longint;                   //total frames
    	      lQuality:Longint;                      //quality factor (for jpeg, default =75)
    	      bHardEncode:WORD;                      //flag of encode by harware
    	      wRes:WORD;
    	      res0:Array [0..4] of Longint;	     //args reserved
    	      //---end commnon--

    	      dbFrameRate:Double;                    //frame rate (default=25, and it is expected rate when it as input)
    	      dbBitRate:Double;                      //bits rate

    	      reserved1:Longint;                     //reserved
    	      res1:Array [0..12] of Longint;	     //args reserved
    end;


    //---used to set and get image info ------
    _mpg4_header_info = Record
    	      //struct _imagesize_info;
    	      lHeadSize:Longint;                     //struct header size
    	      lHorzSize:Longint;	             //width, (default=768 when it as input)
    	      lVertSize:Longint;	             //height, (default=768 when it as input)
    	      lBitCount:Longint;                     //bit count (default=24 when it as input)
    	      lTotalFrame:Longint;                   //total frames
    	      lQuality:Longint;                      //quality factor (for jpeg, default =75) (real 31 level)
    	      bHardEncode:WORD;                      //flag of encode by harware
    	      wRes:WORD;
    	      res0:Array [0..4] of Longint;	     //args reserved
    	      //---end commnon--

    	      dbFrameRate:Double;	             //frame rate (default=25, and it is expected rate when it as input)
    	      dbBitRate:Double;  	             //bits rate, (default=4000000, and it is recommended)
    	      lEncodeMode:Longint;                   //Encode mode, (value range 0~1, 0: double channels, 1:fix code rate as dbBitRate preset.
    			    	                     //default=0, when it as input)
    	      lInterval:Longint;                     //Interval between key frame, (range: 1--300, default =100)
    	      lBFrameNum:Longint;	             //B frame mode, (value range:0~2,  default=0. It is compatible as divx5.0
    			   	                     //=2, little coded data but more encoding times
    	      lQualityIdx:Longint;	             //mpeg4 quality control level index, (value range: 0~6, default=6, mean high level)
    			   	                     //It will be better quality if value greater, but it will need longer times

    	      lpExtraInfo:Pointer;                   //reserved, to store extra infos
    	      res1:Array [0..8] of Longint;	     //args reserved
    end;




    //--get infos of current decoded frame ---------
    _extra_frame_info = Record                       //info of current frm
    	      //--Input
    	      dwFlgSkip:DWORD;	                     //if it=="SKIP" mean skip decoded data, just get params

    	      //--Output of current frm decoded
    	      dwFrmType:DWORD;	                     //type of frm, I,P,B
    	      dwFrmNumber:DWORD;	             //number of frm in origin video stream
    	      dwFrmRatio:DWORD;		             //current frm ratio
    	      dwTimeStamp:DWORD;	             //time stamp (in mili S)
    	      dwDateStamp:DWORD;	             //date stamp
    	      reserved:Array [0..7] of DWORD;        //res
    end;

    //---used to set and get image info ------
    _mjpg_header_info = Record
    	      //struct _imagesize_info;
    	      lHeadSize:Longint;                     //struct header size
    	      lHorzSize:Longint;	             //width, (default=768 when it as input)
    	      lVertSize:Longint;	             //height, (default=768 when it as input)
    	      lBitCount:Longint;                     //bit count (default=24 when it as input)
    	      lTotalFrame:Longint;                   //total frames
    	      lQuality:Longint;                      //quality factor (for jpeg, default =75)
    	      bHardEncode:WORD;                      //flag of encode by harware
    	      wRes:WORD;
    	      res0:Array [0..4] of Longint;          //args reserved
    	      //---end commnon--

    	      dbFrameRate:Double;                    //frame rate (default=25, and it is expected rate when it as input)

    	      dwGetFrmInfo:DWORD;                    //=="GINF" mean to get current frm's infos, and lpExtraInfo points memory to store them
    	      lpExtraInfo:Pointer;                   //points to memory to store extra infos returned by okDecodeImage,
    						     //else it must be NULL
    	      res1:Array [0..13] of Longint;	     //args reserved
    end;


    //--get frame type decoded---------
    _mpeg_frame_info = Record
              lHeadSize:Longint;                     //struct size
    	      lFrameType:Longint;	             //current frame type
    	      lSkip:Longint; 		             //input
    	      reserved1:Longint;                     //reserved
    	      reserved2:Longint;                     //reserved
    	      reserved3:Longint;                     //reserved
    	      reserved4:Longint;                     //reserved
    end;

    //-----------------------------------------------------


    //---used to set and get net-device's config param  ------
    _net_cfg_param = Record
              dwType:WORD;                           //not used, just id (IP,MC address.  =IPADDRESS or MACADDRESS)
    	      bRWFlag:BYTE;                          // =0:read, 1:write
    	      bReset:BYTE;                           // =1 reset immediately after write mac addr, 0: not
    	      szAddress:Array [0..119] of char;      //in format of string.  ip addr, like "168.196.1.1",  //in 10 decimal
    						     //mac addr, like 0x 60 50 40 30 20 10 //in 16 (hexadecimal)
    						     //both address are in local machine order,  high byte first
    	      dwLowAddress:DWORD;                    // in format of 16 decimal, low DWORD responds 0x40302010, string format is "64.48.32.16"
    	      dwHiAddress:DWORD;                     // high DWORD, responds 0x 60 50
    	      lRes:DWORD;                            //reserved
    end;

        TARGET = LPARAM;
        BLOCKINFO = _blockinfo;
        LPBLOCKINFO = ^_blockinfo;
        LPDIBINFO = ^DIBINFO;
        BOARDTYPE = _boardtype;
        BLOCKSIZE = _blocksize;
        RAWFILEPARAM = _rawfileparam;
        LPBOARDTYPE = Array of BOARDTYPE;
    //    LPBOARDTYPE=^_boardtype; //24 bytes
        IMAGESIZE = _imagesize;
        LPIMAGESIZE = ^_imagesize;
        JPEGPARAM = _jpegparam;
        LPJPEGPARAM = ^_jpegparam;
        SETTEXTMODE = _settextmode;
        OKDEVTYPE = _okdevtype;
        LPOKDEVTYPE = Array of _okdevtype;

        JPG2KHEADER = _jpg2k_header_info;
        MPEG2HEADER = _mpg2_header_info;
        MPEG4HEADER = _mpg4_header_info;
        MJPGHEADER = _mjpg_header_info;
        MPEGFRAMEINFO = _mpeg_frame_info;
        NETCFGPARAM = _net_cfg_param;
        EXTRAFRMINFO = _extra_frame_info; //for lpExtraInfo of mjpg to get info of current frm
        LPEXTRAFRMINFO = ^_extra_frame_info;

const
     OK_M10 = 1010;
     OK_M10N = 1010;
     OK_M10M = 1013;
     OK_M10F = 1011;
     OK_M10L = 1014;
     OK_M10H = 1012;
     OK_M20 = 1020;
     OK_M2KC = 1021;

     OK_M20H = 1022;
     OK_M30 = 1030;
     OK_M40 = 1040;
     OK_M50 = 1050;
     OK_M60 = 1060;
     OK_M70 = 1070;
     OK_M80 = 1080;
     OK_M80K = 1081;

//--new updated series
     OK_M10A = 1210;	//
     OK_M10B = 1213;	//OK_M10M:1013
     OK_M10C = 1214;	//OK_M10L/N:1014
     OK_M10D = 1215;
     OK_M10K = 1218;	//OK_M80K
     OK_M11K = 1217;	//

     OK_M20A = 1222;	//OK_M20H:1022
     OK_M20B = 1223;	//110M
     OK_M20C = 1224;	//160M
     OK_M20D = 1225;	//205M
     OK_M20G = 1227;	//oem

     OK_M40A = 1240;	//OK_M40:1041
     OK_M40B = 1243;	//110M
     OK_M40C = 1244;	//160M
     OK_M40D = 1245;	//205M

     OK_M60A = 1260;	//OK_M60:1060
     OK_M60B = 1263;	//110M
     OK_M60C = 1264;	//160M
     OK_M60D = 1265;	//205M

     OK_M50A = 1250;
     OK_M50B = 1253;
     OK_M50K = 1258;
     OK_M51K = 1257;

     OK_M30A = 1230;
     OK_M30B = 1233;
     OK_M30K = 1238;
     OK_M31K = 1237;
     OK_M70A = 1270;
     OK_M70B = 1273;

//64 bits series
     OK_DM20B = 1223;	//140M
     OK_DM20C = 1224;	//160M
     OK_DM20D =	1225;	//205M

//PCI_X seriesC
     OK_XM20_140 = 1323;


//Color series
     OK_C20 = 2020;
     OK_C20C = 2021;
     OK_C30 = 2030;
     OK_C32 = 2032;
     OK_C33 = 2033;
     OK_C30S = 2031;
     OK_C40 = 2040;
     OK_C50 = 2050;
     OK_C70 = 2070;
     OK_C80 = 2080;
     OK_C80M = 2081;
     OK_C82 = 2082;

//RGB series
     OK_RGB10 = 3010;
     OK_RGB20 = 3020;
     OK_RGB30 = 3030;

//Monitor Control series
    OK_MC01 = 4001;
    OK_MC03	=	4003;
    OK_MC10 = 4010;
    OK_MC16 = 4016;
    OK_MC20 = 4020;
    OK_MC30 = 4030;

//--new updated series
     OK_C20A = 2220;
     OK_C23A = 2221;
     OK_C20B = 2223;
		 OK_C21B = 2225;
     OK_C30A = 2230;
     OK_C31A = 2231;
     OK_C30B = 2233;
     OK_C40A = 2240;
     OK_C50A = 2250;
     OK_C60A = 2260;
		 OK_C61A = 2261;
     OK_C60B = 2263;
     OK_C60C = 2264;
     OK_C80A = 2280;
     OK_C80K = 2288;

     OK_RGB10A = 3210;
     OK_RGB11A = 3211;
     OK_RGB10B = 3213;

     OK_RGB20A = 3220;
     OK_RGB21A = 3221;
     OK_RGB20B = 3223;
     OK_RGB20C = 3224;

     OK_RGB30A = 3230;
     OK_RGB30B = 3233;
     OK_RGB30C = 3234;

     OK_RGB60A = 3260;
     OK_RGB60B = 3263;
     OK_RGB60C = 3265;

     OK_VGA40A = 3240;
     OK_VGA40B = 3243;

     OK_MC10A = 4210;
     OK_MC12A = 4212;
     OK_MC16A = 4216;

     OK_MC20A	= 4220;

     OK_MC20B	= 4223;
     OK_MC40B	= 4243;

     OK_MC40B_E	= 4343;

//---pc104+ series
      OK_PC10A = 5210;
      OK_PC16A = 5216;
      OK_PC20A = 5221; //two cards

//PC 51--
      OK_PC20B = 5123; //dvd compress


//PR 53--
    OK_PR10B = 5313; //->rgb10b
    OK_PR20B = 5323; //->rgb20b
    OK_PR30A = 5330; //->rgb30a
    OK_PR170 = 5317; //
    OK_PR30B = 5333; //->rgb30b

    OK_PR30C = 5334; //->rgb30b/two input  **
    OK_PR40A = 5340; //out rgb signal **
    OK_PR43A = 5343; //out 2 comp signal
    OK_PR50A = 5350; //standard out rgb

    OK_PR60C = 5364; //rgb60c with cmp


//PM 54--
    OK_PM10A = 5410; //->m10a
    OK_PM10B = 5413; //->m10b
    OK_PM20A = 5420; //->m20a
    OK_PM20B = 5423; //->m20b

    OK_PM20D = 5426; //->613 special signal cap

    OK_PM50G = 5457; //->m50G special

//---usb series
    OK_USB10A	= 5110;	//line scan capture

//USB 52--
    OK_USB20A	= 5220;	//std color
    OK_USB20B	= 5223;	//non-std b/w capture

//--3.0
//USB3.0 52-- (std)
    OK_USB30A = 5231;	//USB3.0 capture and compress
    OK_USB30B = 5233;	//USB3.0 capture, compress and support sdi


//---cPCI series
    OK_CPC16A	= 5230;   //color 16 channels
    OK_CPC50B = 5253;     //m50b
    OK_CPC50G = 5257;     //m20g oem
    OK_CPC66C	= 5266;   //rgb66c /6u with cmp

    OK_CPC60C	= 5365;   //rgb60c /3u with cmp 53S
    OK_CPC61C	= 5361;   //rgb61c //3u rgb/dvi. comp with 60c
    OK_CPC62C = 5362;     //rgb62c //3u camlink
    OK_CPC63C	= 5363;   //rgb61c //3u lvds

    OK_CPC61E =	5367;     //same as cpc61c (eqaul to PCI-4E)

//CPCI 55--
    OK_CPC12A = 5512;  //color 12 difference channels

    OK_CPC40C =	5540;  //rgb41c lvds(camlink) output /3u
    OK_CPC41C = 5541;  //rgb41c div output /3u
    OK_CPC41D=	5544;  //incl. OK_CPC41C
    OK_CPC40D = 5542;  //(cpc40c revised) lvds output /3u

    OK_CPC43C	= 5543;   //rgb41c /3u 4 comp

//---Digital series
    OK_CL20A = 6120;	//CameraLink
    OK_CL40A = 6140;	//
    OK_CL60A = 6160;	//
    OK_CL20B = 6123;	//
    OK_CL40B = 6143;	//
    OK_CL60B = 6163;	//

    OK_CL20C = 6125;	//
    OK_CL40C = 6145;	//

    OK_LV20A = 6220;	//LVDS
    OK_LV21B = 6224;	//LVDS mpeg-II like c21b
    OK_LV40A = 6240;	//

    OK_LV50A = 6250;	//just output

    OK_LV60A = 6260;	//
    OK_LV20B = 6223;	//
    OK_LV40B = 6243;	//
    OK_LV60B = 6263;	//

    OK_LV20C = 6225;	//
    OK_LV40C = 6245;	//
    OK_LV20G = 6227;	//

//---Line scan series
    OK_LS100A	= 7100;	//LS basic type for Analog
    OK_LS100B	= 7103;	//LS second type for Analog
    OK_LS120A	= 7120;	//LS basic type for CameraLink
    OK_LS120B	= 7123;	//LS second type for CameraLink
    OK_LS200A	= 7200;	//LS second class for Analog



//---FireWare (1394) series
    OK_FW10A = 8410;

//---fibre optical series
    OK_FB10A = 8510;

//---GigE net series
    OK_GN10A = 8610;
    OK_GN20A = 8620;
    OK_GN40A = 8640;      //4 channs
    OK_GN40A_E = 8643;    //PCI_E 4 channs
    OK_GN40A_4E	= 8644;   //PCI_E 4 channs



//---DSP series
    OK_DSP100A = 9100;	//DSP capture process




//---PCI-Express and PCI_X series
//Mono series

//#define		OK_M40A_E				1340	//
//#define		OK_M40B_E				1343	//

//#define		OK_M20B_4E				1423	//
//#define		OK_M40B_4E				1443	//

    OK_M10B_E   = 1313;	//
    OK_M10K_E   = 1318;	//
    OK_M20A_E   = 1322;	//
    OK_M20B_E   = 1323;	//

    OK_M30B_E	= 1333;	//
    OK_M50B_E	= 1353;	//


//Color series
    OK_C20A_E	= 2320;
    OK_C21B_E	= 2325;
    OK_C30A_E	= 2330;

    OK_C61A_E	= 2361;
    OK_C60B_E	= 2363;

//RGB series
    OK_RGB20A_E	= 3320;
    OK_RGB20B_E	= 3323;
    OK_RGB30A_E	= 3330;
    OK_RGB30B_E	= 3333;

    OK_RGB60A_E	= 3360; //cmp
    OK_RGB60B_E	= 3363; //cmp
    OK_RGB60C_E	= 3365; //cmp
    OK_RGB61C_E	= 3366; //DVI/cmp
    OK_RGB60C_X	= 3565; //cmp
    OK_RGB61C_X	= 3566; //DVI/cmp
    OK_RGB61C_4E = 3466; //DVI/VGA/cmp

    OK_VGA40A_E	= 3340;
    OK_VGA41A_E	= 3341;
    OK_VGA40B_E	= 3343;
    OK_VGA41B_E	= 3344;

    OK_VGA51A_E = 3351; //DVI/AUDIO

    OK_VGA40B_4E = 3443;  //PCI-4E
    OK_VGA41A_4E = 3441;  //PCI-4E single DVI/VGA
    OK_VGA41B_4E = 3444;  //PCI-4E two DVI/VGA
    OK_VGA41C_4E = 3445;  //PCI-4E HR DVI

    OK_VGA40A_X	= 3540;
    OK_VGA41A_X	= 3541; //DVI
    OK_VGA40B_X	= 3543;
    OK_VGA41B_X	= 3544; //DVI

//Monitor Control series
    OK_MC10A_E = 4310;	//
    OK_MC12A_E = 4312;	//

    OK_MC30A_E = 4330;
    OK_MC20B_E = 4323;
    //OK_MC40B_E = 4343;

//4E
    OK_MC40A_4E	= 4440;	//
    OK_MC40C_4E	= 4445;	// with comp


//CameraLink
    OK_CL20A_E = 6320;	//CameraLink
    OK_CL40A_E = 6340;	//
    OK_CL60A_E = 6360;	//
    OK_CL20B_E = 6323;	//
    OK_CL40B_E = 6343;	//
    OK_CL60B_E = 6363;	//

//LVDS-RS644
    OK_LV20A_E = 6420;	//LVDS
    OK_LV40A_E = 6440;	//
    OK_LV60A_E = 6460;	//
    OK_LV20B_E = 6423;	//
    OK_LV40B_E = 6443;	//
    OK_LV60B_E = 6463;	//

//SDI
    OK_SDI40A_E	= 6540;	//SDI
    OK_SDI40B_E	= 6543;	//H_SDI

//---Ok sereis Camera
//LVDS-RS644
    OK_AM1530	=	201530; //LVDS


//USB2.0 series
    OK_AM1110	= 201110;       //USB
    OK_AM1111	= 201111;
    OK_AM1310 = 201310;
    OK_AM1410	= 201410;
    OK_AM1510	= 201510;

    OK_AM9010	= 209010;       //for DR
    OK_GAM1610 = 601610;      //for DR
    SUPERCCD_1680	= 201680;	  //$
    SUPERCCD_1681	= 201681;	  //$

    OK_AC1210 = 211210;
    OK_AC1310 = 211310;

    OK_AC168 = 210168;        //oem
    OK_AC168N	= 210169;       //oem

    OK_SM1310	= 301310;
    OK_SC1310 = 311310;
    OK_SC2010	= 312010;
    OK_SC3010	= 313010;

    OK_SM130 = 300130;        //oem

    OK_GSM1410 = 701410;
    OK_GSC1410 = 711410;
    NS_DR16	= 700116;         //oem

//FireWare(1394)
    OK_AM1340	=	201340; //1394

//Optical
    OK_AC1350	= 211350; //

//GigE series (Remote net camera)
    OK_AM1160	= 201160; //
    OK_AM1161	= 201161; //
    OK_AM1360	= 201360; //
    OK_AM1460	= 201460; //
    OK_AM1560	= 201560; //
    OK_AM1561	= 201561; // plus

    OK_AM1565	= 201565; // special for x-ray for GE
    OK_AM1566	= 201566; // special for x-ray

    OK_AM1666 = 201666;   // Kodak sereis

//--67 (GIGE 29x29 sereis)

    OK_AM2067 = 202067; // ccd b/w 2.0 M Pixels
    OK_AC2067 = 212067; // ccd color 2.0 M Pixels
    OK_AM2167 =	202167; // ccd b/w 2.0 M Pixels (double channels)
    OK_AC2167 =	212167; // ccd color 2.0 M Pixels (double channels)

    OK_AM5067 =	205067; // ccd b/w 5.0 M Pixels
    OK_AC5067 =	215067; // ccd color 5.0 M Pixels

    OK_GAM2967 = 602967; // ccd b/w 29 M Pixels

    OK_SM1367 = 301367; // cmos b/w 1.3 M Pixels
    OK_SC1367 =	311367; // cmos color 1.3 M Pixels

    OK_SM5067 =	305067; // cmos b/w 5.0 M Pixels
    OK_SC5067 =	315067; // cmos color 5.0 M Pixels



    //--68 (kodak ccd) (GIGE 2-channel sereis )

    //--1023x1024
    OK_AM1168 = 201168; // (5.5, b/w, 1 MPix, single net interface) #
    OK_AC1168 =	211168; // (5.5, color, 1 MPix, single) #
    OK_AM1268 =	201268; // (5.5, b/w, 1 MPix, double)  #
    OK_AC1268 =	211268; // (5.5, color, 1 MPix, double) #

    //--(1600x1200)
    OK_AM2168 =	202168; // (5.5, b/w, 2 MPix, single)
    OK_AC2168 =	212168; // (5.5, color, 2 MPix, single)
    OK_AM2268 =	202268; // (5.5, b/w, 2 MPix, double)
    OK_AC2268 =	212268; // (5.5, color, 2 MPix, double)

    //--(1920x1080)
    OK_AM2368 =	202368; // (5.5, b/w, 2 MPix, single) #
    OK_AC2368 =	212368; // (5.5, color, 2 MPix, single)
    OK_AM2468 = 202468; // (5.5, b/w, 2 MPix, double)  #
    OK_AC2468 =	212468; // (5.5, color, 2 MPix, double) #

    //--(1920x1080)
    OK_AM2568 =	202568; // (7.4, b/w, 2 MPix, single)
    OK_AC2568 =	212568; // (7.4, color, 2 MPix, single)
    OK_AM2668 =	202668; // (7.4, b/w, 2 MPix, double) #
    OK_AC2668 =	212668; // (7.4, color, 2 MPix, double) #

    //--(2336x1752)
    OK_AM4168 =	204168; // (5.5, b/w, 4 MPix, single)
    OK_AC4168 =	214168; // (5.5, color, 4 MPix, single)
    OK_AM4268 =	204268; // (5.5, b/w, 4 MPix, double) #
    OK_AC4268 =	214268; // (5.5, color, 4 MPix, double) #

    //--(2048x2048)
    OK_AM4568 =	204568; // (7.4, b/w, 4 MPix, single)
    OK_AC4568 =	214568; // (7.4, color, 4 MPix, single)
    OK_AM4668 =	204668; // (7.4, b/w, 4 MPix, double) #
    OK_AC4668 =	214668; // (7.4, color, 4 MPix, double) #

    //--(3296x2472)
    OK_AM8168 =	208168; // (5.5, b/w, 8 MPix, single)
    OK_AC8168 =	218168; // (5.5, color, 8 MPix, single)
    OK_AM8268 =	208268; // (5.5, b/w, 8 MPix, double) #
    OK_AC8268 =	218268; // (5.5, color, 8 MPix, double) #


    //--(4896x3264)
    OK_GAM1568 = 601568; // (5.5, b/w, 16 MPix, single)
    OK_GAC1568 = 611568; // (5.5, color, 16 MPix, single)
    OK_GAM1668 = 601668; // (5.5, b/w, 16 MPix, double) #
    OK_GAC1668 = 611668; // (5.5, color, 16 MPix, double)

    //--(4864x3232)
    OK_GAM1768 = 601768; // (7.4, b/w, 16 MPix, single)
    OK_GAC1768 = 611768; // (7.4, color, 16 MPix, single)
    OK_GAM1868 = 601868; // (7.4, b/w, 16 MPix, double) #
    OK_GAC1868 = 611868; // (7.4, color, 16 MPix, double)


    //--(6576x4384)
    OK_GAM2568 = 602568; // (5.5, b/w, 29 MPix, single)
    OK_GAC2568 = 612568; // (5.5, color, 29 MPix, single)
    OK_GAM2668 = 602668; // (5.5, b/w, 29 MPix, double) #
    OK_GAC2668 = 612668; // (5.5, color, 29 MPix, double)


//--

    OK_AM1751 = 201751;   // e2v sereis, customized

    OK_AC1260 = 211260; //
    OK_AC1360 = 211360; //
    OK_AC1361 = 211361; //

//--Linear scan with GigE interface
    OK_LM1060 = 101060; //1K
    OK_LM2060 = 102060; //2K
    OK_LC2060 = 112060; //2K color
    OK_LC4060 = 114060; //4K color


//------------------------------------
//Intellegent Camera
    OK_IC1200 = 181200; //
    OK_IC1500 = 181500; //

    OK_IM1161 = 171161; // b/w 640x480, Gnet
    OK_IM1160 = 171160; // b/w 7680x576, Gnet



//------Embeded parts-------------------------------------
//GigE converter
    OK_GE130 = 10130;   //
    OK_GE400 = 10400;   //

    OK_DX160 = 21160;   // GigE CCU (type I)
    OK_DX260 = 21260;   // GigE CCU (type II)

//--error code

    ERR_NOERROR = 0;	        //no error
    ERR_NOTFOUNDBOARD = 1;	//not found available ok board

    ERR_NOTFOUNDVXDDRV = 2;	//not found ok vxd driver
    ERR_NOTALLOCATEDBUF = 3;	//not pre-allocated buffer from host memory
    ERR_BUFFERNOTENOUGH = 4;	//available buffer not enough requirment
    ERR_BEYONDFRAMEBUF = 5;	//capture iamge size beyond buffer

    ERR_NOTFOUNDDRIVER = 6;	//no driver found
    ERR_NOTCORRECTDRIVER = 7;	//driver not correct

    ERR_MEMORYNOTENOUGH = 8;	//memory not enough
    ERR_FUNNOTSUPPORT = 9;	//the function not support
    ERR_OPERATEFAILED = 10;	//something wrong with the operation

    ERR_HANDLEAPIERROR = 11;	//the handle to okapi function wrong
    ERR_DRVINITWRONG = 12;	//something wrong with driver initialize

    ERR_RECTVALUEWRONG = 13;	//the rect set wrong
    ERR_FORMNOTSUPPORT = 14;	//the form set not support by the board

    ERR_TARGETNOTSUPPORT = 15;	//the target not support by this function
    ERR_NOSPECIFIEDBOARD = 16;	//not found specified board correctly sloted

//--format defines
    FORM_RGB888 = 1;	//rgb format
    FORM_RGB565 = 2;
    FORM_RGB555 = 3;
    FORM_RGB8888 = 4;
    FORM_RGB332 = 5;
    FORM_RGB8886 = 18;

    FORM_YUV422	= 6;	//yuu format
    FORM_YUV411 = 7;
    FORM_YUV16 = 8;
    FORM_YUV12 = 9;
    FORM_YUV9 = 10;
    FORM_YUV8 = 11;

    FORM_GRAY888 = 12;	//gray format
    FORM_GRAY8888 = 13;
    FORM_GRAY8 = 14;
    FORM_GRAY10 = 15;
    FORM_GRAY12 = 16;
    FORM_GRAY14	= 17;
    FORM_GRAY16	= 19;
    FORM_GRAY4 = 20;	 //added 090822
    FORM_GRAY12PACKED =	21;	 //added 110602
    FORM_GRAY10PACKED =	22;	 //added 110602

    FORM_BAYGR8 = 23;	//bayer format
    FORM_BAYRG8	= 24;	//added on 20140926
    FORM_BAYGB8	= 25;
    FORM_BAYBG8	= 26;

    FORM_BAYGR16 = 27;
    FORM_BAYRG16 = 28;
    FORM_BAYGB16 = 29;
    FORM_BAYBG16 = 30;



//--mask command
    MASK_DISABALE = 0;	//turn of mask
    MASK_POSITIVE = 1;	//0 win clients visible, 1 video visible
    MASK_NEGATIVE = 2;	//0 for video 1 for win client (graph)


//--tv system standard
    TV_PALSTANDARD = 0;	        //PAL
    TV_NTSCSTANDARD = 1;	//NTSC
    TV_NONSTANDARD = 2;	        //NON_STD
    TV_HDTVSTANDARD = 3;	//HDTV_STD
//	TV_SECAMSTANDARD		4	//SECAM

//--HDTV sub mode
    HDTV_480P = 1;             //480 Lines Progressive scan
    HDTV_720P = 2;             //720 Lines Progressive scan
    HDTV_1080I = 3;            //1080 Lines Interlaced scan
    HDTV_1080P = 4;            //1080 Lines Interlaced scan


    TV_PALMAXWIDTH = 768;
    TV_PALMAXHEIGHT = 576;

    TV_NTSCMAXWIDTH = 640; //720
    TV_NTSCMAXHEIGHT = 480;


//-----defines lParam for get param
    GETCURRPARAM = -1;

//-----sub-function defines for wParam of SetVideoParam
		//wParam cab be one of the follow
    VIDEO_RESETALL = 0;         //reset all to sys default
    VIDEO_SOURCECHAN = 1;       //lParam=0,1.. Comp.Video; 0x100,101...to Y/C(S-Video), 0x200,0x201 to RGB/VGA Chan.Input,
    				//0x400,0x401 to YPrPb, 0x800,0x801 to DVI/HDMI, 0x900,0x901 to HDMI(YPbPr)
		                // return max support Comp. Video channles when input lParam=0xff.
				// as same way return max s-video channeles when input lParam=0x1ff.
				// and return max rgb/vga video channeles when input lParam=0x2ff.
				// and return max YPrPb video channeles when input lParam=0x4ff.
				// and return max DVI/HDMI(RGB) channeles when input lParam=0x8ff.
				// and return max HDMI(YPbPr) channeles when input lParam=0x9ff.
				// and return max SDI channeles when input lParam=0xAff.


    VIDEO_BRIGHTNESS = 2;       //LOWORD is brightness, for RGB HIWORD is channel (0:red, 1:green, 2:blue)
    VIDEO_CONTRAST = 3;         //LOWORD is contrast, for RGB HIWORD is channel (0:red, 1:green, 2:blue)

    VIDEO_COLORHUE = 4;         //LOWORD is hue of color,  for YUV/YPbPr HIWORD=0 is for V/Pr, =1 for U/Pb
    VIDEO_SATURATION = 5;       //LOWORD is saturation of color,  for YUV/YPbPr HIWORD=0 is for V/Pr, =1 for U/Pb
    VIDEO_GAINADJUST = 18;      //gain adjust, some card support range 0~255, some just 0~3
    VIDEO_PHASEADJUST = 20;     //phase adjust

    VIDEO_RGBFORMAT = 6;        //when return, low word is format code
    VIDEO_TVSTANDARD = 7;       //Main Mode:LOWORD 0 PAL, 1 NTSC, 2 Non-stadard, HDTVSTANDARD,
				//Sub Mode: HIWORD 1 HDTV_480P, ...
    VIDEO_SIGNALTYPE = 8;       //LOWORD 0: non-interlaced(progressive), 1: interlaced
				//2:single pixel, 3:double pixels (for digital signal), 4:double pixels (inverse pixel order)
     			        //5:treble pixels, 6:quad pixels
				//HIWORD: trigger mode(/slot in field header for standard tv video).
				//0= continu. signal, =1: edge-trigger(hardware or software)
     			        //for camera, =2: pulse width trigger, =3: extern sync mode, =4: keep one after trigger,
     			        //=5: keep last one after trigger,
				//when lParam==-2, just get capability of LOWORD, if return -1: not support;
				//when lParam==-3, just get capability of HIWORD, if return -1: not support
    VIDEO_SYNCSIGCHAN = 10;     //LOWORD: sync line of source channel, =0:Red,1:Grn,2:Blue, 3:Sync,4 H.V.Sync;
				//usually =1, 3 or 4 when vidoe input is rgb source
                                //HIWORD: which source the sync line is in. =0,1,..for RGB source 0,1,
				//=0x100,0x101,... for comp.video source 0,1, (in this case(comp. video) LOWORD has no mean more)
    VIDEO_IMAGESOURCE = 36;     //LOBYTE(BYTE0): 0(defalut): alive(continuous), 1: last image, 2:black, 3: white, 4: vertical-lines
				//5: vertical-lines changing
				//BYTE1: select chann(based 0) to store or process
				//b16=1: test light on, b17:histogram in pic

    VIDEO_AUXMONCHANN = 11;     //BYTE0(LOBYTE): monitor video source chann on aux monitor for MC30
				//BYTE1(B8:15) special for LV20G
				//HIWORD select out video channel(when more than 1, e.g for CCU)

    VIDEO_RECTSHIFT = 9;        //video rect shift,  makelong (x,y)
    VIDEO_RECTSHIFTEX = 19;     //general video active rect shift for all,  makelong (x,y)
				//replace for VIDEO_RECTSHIFT

    VIDEO_AVAILRECTSIZE	= 12;   //makelong(horz,vert). horz available pixels per scan line and
				//vert available lines per frame
    VIDEO_FREQSEG = 13;         // set video pixel frequency range
				//LOWORD, 0:Low(7.5~15MHz),  1:middle(15~30), 2:High(30~60), 3:ultra(60~120), 4:very(>120)
				//HIWORD =1: mean LOWORD is specified frequency value (like 120 mean 120MHz)

    VIDEO_MISCCONTROL = 16;     //miscellaneous control bits
				//b0:-satur, b1:- contr (for c20, c30)
				//b2:agc, b3:gama, b4:b/w,
          			//b5:fast mode (for c30b)
				//b6: 1: std high bit mode (like 12...), 0: compatible 10b mode for LVDS digital input
				//b7: 1: switch off auto zoom mode when output is different from source
				//b8: 1:VTR mode, 0:auto mode
				//b9: 1: close language select, 0:open
				//b10: 1: inverse gray of out video
				//b11: 1: enable electronic circle
				//b12: 1: enable rect to measure visible

    VIDEO_ENABLEGRAPHS = 17;    //enable graph. LOBYTE,b0: enable cap-graph; b1: enb out-graph.  HIBYTE graph frm sel

//--set local device
    VIDEO_SETBADPTNUM =	25;     // set number of bad point, LOWORD= number(based 1).  and  HIWORD=1 mean enable removing bad points, 0: stay there	    //
    VIDEO_SETBADPTPOS =	26;     // set position of bad point, LOWORD=x, HIWORD=y

    VIDEO_TAGFRMCOUNT =	27;     // LOWORD=1: turn on frame counter and tag it to each frame, =0 off;
				// HIWORD=1 reset frame counter
//--
    VIDEO_SETWATCHDOG =	28;     // set watchdog, LOWORD= 0: off wotchdog, >0: enable, and it is timer in seconds(1~255)
    VIDEO_SETDATETIME =	29;     // set and get date and time embeded in hardware. lParam should be pointer to struct tm (include date and time)
				//if lParam=0, it will take current system date and time; You can get current datetime of device by setting tm.tm_year=-1
    VIDEO_RESETSYSTEM =	30;     // bits0=1 restart system timer, b1=1: clear system's flash memory

    VIDEO_SETDELAYLINES = 39;   //(for LineScan camera) LOWORD is delay lines between two channels(R,G, or B), HIWORD =0 mena R is first channel, =1: B is first one

//--set params of video out to the other device

    VIDEO_OUTLINEPERIOD = 14;   //LOWORD out line period (in 0.54 us) generated by board, when HIWORD==0:in 0.54 us, =1: in 0.1 vs, =2: in 0.01vs ...
    VIDEO_LINEPERIOD = 14;      //LOWORD out line period (in 0.54 us) generated by board, when HIWORD==1:in 0.1 vs, ...


    VIDEO_OUTFRAMELINES	= 15;   //out lines per frame generated by board, HIWORD is local sync
    VIDEO_FRAMELINES = 15;      //when outlines<2/3* caspture vert lines, it will zoom vert to half lines
				//for digtal cards
    VIDEO_OUTSYNCMODE = 22;     //out sync mode, b0:in grn, b1:comp sync, b2:interlace
                                //b3:neg pole of horz sync;
				//b4~5:vert half or double. 0:auto set (when VIDEO_FRAMELINES set is 1/3 difference from CAPTURE_VERTLINES,
				//0: auto-set, 1=forced half, 2=forced double, 3: forced set no
     			        //b6:neg pole of vert sync
				//HIWORD: b16~19: b16=1: off out video channel 0, b17=1: off out video channel 1. etc.
				//(only two channs for cpc50b, 4 channs for PR43A)

    VIDEO_OUTHORZPIX =	23;     // set out horz total pixel on the monitor
    VIDEO_OUTXYOFFSET = 24;     // set offset of pixels in horz and vert directions on monitor

    VIDEO_OUTHVSYNCWID = 41;    // set out horz and vert sync width (in unit pixle and line). LOWORD is for horz sync and HIWORD is for vert sync.

    VIDEO_OUTWINDOWLEVEL = 40;  // set gray level window's location (start pos) and its width for high bits (>8)
    				// LOWORD = middle gray level, HIWORD = width, turn of when HIWORD=0;


    VIDEO_OUTMODESET = 38;      //(for cpc41c)set mode of out video. LOWORD(mode)=0: no action, =1: pause, =2: resume, =3: forward when HIWORD>0, backward when HIWORD<0
    				//=4: go to specified frame number(=HIWORD), =5: step to number(=HIWORD, may be negative) of frames relative to current frame

    VIDEO_PARTIALMODE =	31;     //partial mode, 0(default): normal(global) mode, non 0: partial mode
				//when partial mode LOWORD= start line number, HIWORD= end line number

//--set some rect to process
    VIDEO_ELLIPSEOFFSET	= 32;	//ellipse(electronic circle) offset (left,top), makelong(horz left offset,vert top offset)
    VIDEO_ELLIPSESIZE = 33;	//ellipse(electronic circle) size (width, height), makelong(horz width, vert hight)

    VIDEO_MEASUREOFFSET = 34;   //for IBS, measure rect's offset (left,top), makelong(horz left offset,vert top offset) for IBS...
    VIDEO_MEASURESIZE = 35;	//for IBS, measure rect's size (width, height), makelong(horz width, vert hight)


    VIDEO_CURRHISTOGRAM	= 37;   //just get current histogram of specified measure rect (default for whole image). return length (256 for gray 8).
										            //lParam=1: enable evaluate histogram; =0; disable; =-1; just return length,; else is pointer to address to store histogram in INT32, =1;
//max=37

//-----sub-function defines for wParam of SetCaptureParam
		                //wParam cab be one of the follow
    CAPTURE_RESETALL = 0;       //reset all to sys default
    CAPTURE_INTERVAL = 1;       //LOWORD is number of frm interval, mean take one frm every LOWORD+1 frames;
				//HIWORD is about number per 10 seconds (frm rate). LOWORD is valid only HIWORD is 0
    CAPTURE_CLIPMODE = 2;       //LOWORD: clip mode when video and dest rect not same size
			        //HIWORD: if captrure odd and even field crosslly
    CAPTURE_SCRRGBFORMAT = 3;   //when return, loword=code, hiword=bits
    CAPTURE_BUFRGBFORMAT = 4;
    CAPTURE_FRMRGBFORMAT = 5;
    CAPTURE_BUFBLOCKSIZE = 6;   //lParam=MAKELONG(width,height)
				//if set it 0 (default), the rect set by user will be as block size
    CAPTURE_HARDMIRROR = 7;     //LOWORD mirror: bit0 x, bit1 y; default for both capture and playback
				//when lParam==-2, if return -1: not support output mirror indepent from capture;
				//Note when lParam's b7=1: mean set capture and playback seperately.
				//b4:x, b5:y for output mirror (if support indepent),
                                //
				//HIWORD special rotate: b16:17: special angle rotate, b16~17=1: rotate 90 degree left, =2: 90 right, =3 180 degree
				//when lParam==-3, check if support rotate special angle, return -1, not support
    CAPTURE_ANGLEROTATE	= 34;   //arbitrary angle rotate.  LOWORD b0~11: angle to ratate in degree (1 represent 1/10 degree)
				//when lParam= -2, if return -1: mean not support output rotate indepent from capture.
				//HIWORD, b31=1 mean set capture and playback seperately.
				//if so, b16~27: angle to ratate in degree (1 represent 1/10 degree)
				//This set wiil be ignored when HIWORD in CAPTURE_HARDMIRROR is not 0

    CAPTURE_VIASHARPEN = 8;	//sample via sharpen filter
    CAPTURE_VIAKFILTER = 9;     //sample via recursion filter
				//when lParam==-2, just get capability of LOWORD, if return -1: not support;
				//when lParam==-3, just get capability of HIWORD, if return -1: not support

    CAPTURE_SAMPLEFIELD = 10;   //0 in field (non-interlaced), 1 in frame (interlaced), (0,1 are basic)
			      	//2 in field but keep expend row,3 in field but interlaced one frame
				//(2,4 can affect only sampllng field(frame) by field(frame) )
				//in 3 up-dn frame
    CAPTURE_HORZPIXELS = 11;	// set max horz pixel per scan line
    CAPTURE_VERTLINES = 12;	// set max vert lines per frame

    CAPTURE_SCROFFSETVID = 21;  //set screen offset in video's rect just for screen scroll
				//affecting Capture to SCREEN and ConvertRect to or from SCREEN

    CAPTURE_ARITHMODE = 13;     //arithmatic (and model image) mode  LOWORD =0:no, =1:V-M, =2:V+M, =3:V+M
    CAPTURE_TO8BITMODE = 14;    //the mode of high (eg. 10 bits) converted to 8bit
				//HIWORD(lParam)=0: linear scale,
				//HIWORD(lParam)!=0:clip mode, LOWORD(lParam)=offset

    CAPTURE_SELRGBDATA = 37;    //LOWORD: select some rgb channel's data to capture as gray image (cpc61c)
                                //0: default for all, 1:red, 2:green, 3:blue


    CAPTURE_SEQCAPWAIT = 15;	// bit0 if waiting finished for functions of sequence capturing and playbacking
				//bit1 if waiting finished capture then call callback function

    CAPTURE_TRIGCAPTURE	= 17;   //set triggered capture, LOWORD cap no of fields, HIWORD delay fields after trigger

    CAPTURE_TURNCHANNELS = 18;  //turn channels when sequence capture
				//b0~6 for turn number (max 127),
				//b8~23(16) mask 0~15 channles, b7=1 keep this pos
				//b28~31, interval in turn, mean turn one time every interval

    CAPTURE_MISCCONTROL = 16;   //miscellaneous control bits
                                //b0: 1: forced okCaptureByBuffer or okGetSeqCapture controled by interrupt
				//b1: 1: take one by one to okCaptureSequence, and okCaptureByBuffer or okGetSeqCapture controled by interrupt
                                //bit2: 1: one by one for usb20
				//b3: 1: capture all 12 bits, 0: capture 10 bits signal for 12 cards like LV20B...
				//b4: 1: horz count from sync's up-edge; 0: down-edge for some cards like LVDS etc.
				//b5: 1: vert count from sync's up-edge; 0: down-edge for some cards like LVDS etc.
				//b6: 1: partial mode for camera, 0: global mode (default)
				//b7: 1: forced to okCaptureTo and okCaptureActive changed to okCapturebyBuffer
				//    note: this bit can be set only when its respond bit in hiword is 1.
				//b8: 0,1 x align adjust for Bayer format
				//b9: 0,1 y align adjust for Bayer format
				//b10: 1 enable pass lut/gamma
				//b11:1 take 8 frms as buffer for okCaptureByBuffer, default take 2 frms

//--
    CAPTURE_SETLATENCY	= 24;   //set PCI latency, default =0xf8, it is better to set to 0x18 when multi-cards
    CAPTURE_SLEEPTIMES = 25;    //relex times and set max times to wait for all sequence capure functions.
      				//LOWORD: a level to release cpu times. 0: disable, 1:system auto (default), >=2 specified level
				//HIWORD: max wait times (in unit 10 milli-second) to wait to next frame. 0:system auto (default).

//--set some camera params
    CAPTURE_EXPOSETIME = 20;    //(like camera) set exposed time, in unit us (microsecond), -2: get max valid exponsetime
    CAPTURE_DELAYEXPOSE	= 27;   //(for camera) set delay time to expose for camera, in unit us (microsecond) from the Basetime (ususally begin after a ex-trigger)

    CAPTURE_FRAMERATE =	22;     //for area camera, LOWORD is transfer frame rate (be equa less current hardware frm rate set); HIWORD is hardware frm rate of camera,
    				//and default: HIWORD=0 mean set to max frm rate to support. when lParam=-2, return how many classes of (hardware) frm rate to support,
    				//lParam=-3, return max (hardware) frame rate to support
    				//for line scan camera, LOWORD is line rate (Lines/S) and HIBYTE be set to 0x80;

    CAPTURE_SETTEMPER =	23;     //for camera, set camera temperature expected, and to get current real temperature of camera when set -2

    CAPTURE_WHITEBALANCE = 26;  //for camera, set white balance for camera, LOWORD=0: off, =1:onetime, =2:always
				//HIWORD=0: default(auto), =1: daylight, =2:fluorescence, =3 incandesent lamp,...
    CAPTURE_SETBINNINGMODE = 28;//for camera, LOWORD set binning mode, 0:normal mode ,when BYTE1=0, BYTE0=0,1: 1x1, =2: 2x2, =3: 3x3, ...
				//when BYTE1!=0, mean BYTE0 is binning number on x-direction, BYTE1 is in y-direction
     			        //HIWORD is soft binning (sample ratio), default=0 mean take whole iamge, when BYTE3=0, BYTE0=0,1: whole, =2: 1/2x1/2
     			        //when BYTE3!=0, mean BYTE2 is sample ratio in x-direction and BYTE3 is in y-direction

    CAPTURE_ENBCAMFUNC = 29;    //for camera, enable camera's functions, b0: auto-adjust mode, and then BYTE2(when non 0) is specified target gray(8Bits);
				//b1: gray stretch; b2: histogram equaliize;
				//b3: enable removing isolated spot, and then if BYTE3 (when non 0 ) is specified gray threshold (8Bits)

    CAPTURE_GAMMAFACTOR	= 30;   //for camera, set gamma factorX100 (it is between 0~2 for some camera)

    CAPTURE_FLATFIELDING = 36;  //for camera, frame grabber,  flat fielding (shadow correct),
				//LOWORD=1: capture a dark field in BUFFER 0, =2; a bright one in BUFFER 1, =3: generat correct model
				//HIWORD=1 enable flat field correct with self-created model, =0x100: disable
//--
    CAPTURE_SETCOMPPARAM = 31;  //LOWORD: qualitiy factor(1~100 for jpg,mjpg), HIWORD: specify compress format(1=JPG, 2=PNG, 3=TIFF, ...)

    CAPTURE_PACKETINTERVAL = 32;//set interval(in 10 vs) between two packets to send in order to control transfer rate (for capture device based net)
										              //0: auto-mode, default=0, genarally max is about 6000000(60Seconds). when lParam= -2 return true max value
    CAPTURE_PACKETSIZE = 33;    //set packet size in byte (for capture device based net), min=8, default=1500, max is 2048
    CAPTURE_WAITASKRESEND = 35; //wait how many packets to ask re-send when some packet was missing (for capture device based net)
//max=36

//#define		CAPTURE_OUTHORZPOS		20	// set out horz offset and width on the monitor
//#define		CAPTURE_OUTVERTPOS		21	// set out vert offset and height on the monitor
//#define		CAPTURE_OUTHORZPIX		22	// set out horz total pixel



//----defines sub-param lParam for CAPTURE_SAMPLEFIELD
     SAMPLE_INFIELD = 0;        //in field (non-interlaced)
     SAMPLE_INFRAME = 1;        //in frame of interlaced fields
				                        //the above two (0,1) are basic
     SAMPLE_FIELDEXP = 2;       //in field but expend (keep expend row)
     SAMPLE_UPDNFRAME = 3;      //in frame of up-downed fields
     SAMPLE_FIELDINTER = 4;     //in field but interlaced to one frame, from even
     SAMPLE_INTOPFIELD	= 5;    //in field just top field


//-----defines sub-param lParam for CAPTURE_CLIPMODE
     RECT_SCALERECT = 0;
     RECT_CLIPCENTER = 1;
     RECT_FIXLEFTTOP = 2;
					//in condition video rect great than screen rect:
					//if RECT_SCALERECT video rect will be scaled to match screen rect if it can. else
					//video rect will be adjusted to match screen rect
					//(1: center, centerize video rect position according size of dest, it will affect VIDEO's rect
					//set by okSetTargetRect(hBoard,VIDEO,lprcVideo);
					// 2: left-top fixed, take left-top of current video's rect and same size rect as dest)


//-----sub-function defines for wParam of SetDeviceParam
		//wParam cab be one of the follow
		DEVICE_SETDEVMEMORY = 0;        //set or get all setable parameters to and from device with memory,
      	                                        //lParam=-1: get device-memory's params as device current , lParam=0: store device's current param to device-memory,
						//=1: restore all params to hardware default
					        //(for camera, CCU,) this func will be called in func okOpenBoard to get and okCloseBoard to set

                DEVICE_SETIPADDRESS = 1;        //set or get new ip address of net device. lParam is structure NETCFGPARAM pointer
		DEVICE_GETMACADDRESS = 2;       //only get mac address of net device. lParam is structure NETCFGPARAM pointer

		DEVICE_GETACCEPTTHREAD = 3;     //get handle of accept thread for capturing image from net device
		DEVICE_GETPARAMCHANGED = 4;     //get changed info which group parameters were set and reset the flag after call

//-----sub-function defines for lParam of PutSignalParam
		PUTSIGNAL_TRIGGER = 1;          //LOWORD output 1 trigger signal; HIWORD output a soft-emulation trigger
		PUTSIGNAL_VERTSYNC = 2;         //enbale video vertical sync. output
					        //(for GPIO,...)
  	        PUTSIGNAL_SYNCSTART = 3;        //set start number after begin of reset pulse signal(Vertical). in unit of line pulse number
					        //(special for LineScan)
		PUTSIGNAL_SYNCCOUNT = 4;        //set count number after start signal to enbale capture. in line pulse
		                                //(special for LineScan)

		PUTSIGNAL_DELAYSYNC = 5;        //set delay times to output sync pulse from the Basetime. in unit of us
					        //(for camera, CCU, ...)
		PUTSIGNAL_SYNCWIDTH = 6;        //set sync pulse's width (in unit of us ) wihich set by PUTSIGNAL_DELAYSYNC.
					        //(for camera, CCU, ...) 	 //	note: it is positive pusle when b31 is 1
		PUTSIGNAL_STARTCONSYNC = 11;    //start sync signals as above. LOWORD is repeat period (in unit of ms) count from the Basetime,
					        //(for CCU, )	//HIWORD (usually is 0) is a extra delay time(in ms) to the Basetime from specified ex-Trigger


		PUTSIGNAL_SETVOLTRANGE = 12;    //set output voltage range (like ibs for CCU), in unit of 0.1 Voltage, LOWORD=min value, HIWORD max
					        //(for CCU,)
		PUTSIGNAL_FEEDBACKFACT = 13;    //set feedback factor, value range 1~16, more big more fast and sensitivity
		                                //(for CCU,)

		PUTSIGNAL_SETFLASHMODE = 8;     //set flash lamp, LOWORD = 0: default(auto), =1: by extra trigger, =2: single by DSP, =3; continue )
					        //(for IC1200, )	//HIWORD: interval of flash, (1~65535) in us

		PUTSIGNAL_EXTRIGDELAY = 7;      //set delay time (in 10us) to generate a negtive trigger(about 20VS width) after received a ex-trigger
					        //(for gpio )
		PUTSIGNAL_SETGPIODIR = 9;       //set GPIO input or output, 0: input, 1:output (b0~31 for 32 io ports)
					        //(for gpio )
		PUTSIGNAL_SETGPIOLEV = 10;      //set GPIO low or hight level, 0: low level, 1: high
					        //(for gpio )

		PUTSIGNAL_SETLENS = 14;         //set param of lens, LOBYTE(BYTE0) for aperture,

		PUTSIGNAL_SETOPTFILTER = 15;    //set param of optical filter, LOBYTE(BYTE0) for light filter,
//max=15




//-----sub-function defines for lParam of okSetConvertParam
    CONVERT_RESETALL = 0;       //reset all to sys default
    CONVERT_FIELDEXTEND = 1;    //field extend
    CONVERT_PALETTE = 2;        //set convert palette (just for 8 to 24 or 32)
                                //lParam=0: restore system default, >0: set new palette (BYTE) pointer and length=256
    CONVERT_HORZEXTEND = 3;     //horzental extend (integer times)
                                //CONVERT_HORZSTRETCH = 4;    //horzental stretch (arbitrary number times)
    CONVERT_MIRROR = 5;         //x and y mirror
    CONVERT_UPRIGHT = 6;        //up to righ(=1)(rotate right 90 D) or left (=2) (rotate left 90 D
    CONVERT_NOSYNCSCREEN = 7;   //1 no wait for sync of vertical (just when to WND for CaptureByBuffer)
				//b13
    CONVERT_WINDOWLEVEL	= 10;   //set gray level window's location( middle pos) and its width, mainly for hight gray(>=8bits) to 8bits
				//Also for its gray of some channel is 8 bits, either src or dst
				// LOWORD=middle, HIWORD=width. HIWORD=0 (default) mean no convert (it (HIWORD) should be 0 usually)
				//this set valid only CONVERT_LEVELMAPLUT as belowed was set to 0
    CONVERT_LEVELMAPLUT	= 11;   //set (copy) gray level map LUT. lParam=0 (default): off, >0: set a pointer of LUT in WORD,
				//which must be WORD pointer anyway. LPWORD[0] is bits of gray level
				//(i.e. it is 8 for GRAY8, GRAY888, RGB888..,it is 16 for GRAY16), and they are true
				//elements of LUT from LPWORD[1].
				//whose max value in this LUT should be <= max value of dest to convert
				//it must be unset by lParam=0 after finishing convert

//-----defines lParam for wParam=CONVERT_FIELDEXTEND in okSetConvertParam
//--field extend mode
	  FIELD_JUSTCOPY = 0;           //just copy row by row
	  FIELD_COPYEXTEND = 1;         //copy one row and expend one row (x2)
	  FIELD_INTERLEAVE = 2;         //just copy odd(1.) rows (/2)
	  FIELD_INTEREXTEND = 3;        //copy one odd row and expend one row
	  FIELD_COPYINTERPOL = 4;       //copy one odd row and interpolate one row
	  FIELD_INTERINTERPOL = 5;      //copy odd row and interpolate even row

	  FIELD_INTEREVEN = 6;          //just copy even(2.) rows (/2)
	  FIELD_INTEREXTEVEN = 7;       //copy one even row and expend one row
	  FIELD_JUSTCOPYODD = 8;        //just copy odd rows to odd rows
	  FIELD_JUSTCOPYEVEN = 9;       //just copy even rows to even rows
	  FIELD_ODDEVENCROSS = 10;      //copy odd and even crossly

	  FIELD_COPYROWTOODD = 11;      //copy row by row and to odd place
	  FIELD_COPYROWTOEVEN = 12;     //copy row by row and to even place

                                        //just for the case without bit converting

//-----sub-function defines for lParam of GetSignalParam
		SIGNAL_VIDEOEXIST = 1;    //0 video  absent, 1 exist
		SIGNAL_VIDEOTYPE = 2;     //0 field, 1 interlaced
		SIGNAL_SCANLINES = 3;     //scan lines per frame
		SIGNAL_LINEFREQ	= 4;      //line frequency
		SIGNAL_FIELDFREQ = 5;     //field frequency
		SIGNAL_FRAMEFREQ = 6;     //frame frequency
		SIGNAL_EXTTRIGGER = 7;    //extern trigger status, 1 trigger
		SIGNAL_FIELDID = 8;       //Field ID 0 odd, 1 even
		SIGNAL_VIDEOCOLOR = 9;    //color(1) or B/W(0)
		SIGNAL_TRANSFERING = 10;  //1 transfering video data
		SIGNAL_CAPFINISHED = 11;  //capture finished
		SIGNAL_HORZSYNCTIME = 12; //time of horz sync header in ns
		SIGNAL_VERTSYNCTIME = 13; //time of vert sync header in ns
		SIGNAL_SYNCPOLARITY = 14; //b0: horz sync pol, b1:vert sync. 0:negtive, 1:positive
		SIGNAL_HORZVALPOS = 15;   //horz edge and size of validate area, LOWORD is width, HIWORD is edge
		SIGNAL_VERTVALPOS = 16;   //vert edge and size of validate area, LOWORD is height, HIWORD is edge
		SIGNAL_VIDEOCHANGED = 17; //video signal changed since last call to any items of this func, 1: changed
		SIGNAL_NETCONNECT = 18;   //status of net(or USB...) connected with capture device, 0: not connected
		SIGNAL_FIELDFREQEX = 19;  //field frequency (number of field per 1000 Seconds)
		SIGNAL_FRAMEFREQEX = 20;  //frame frequency (number of frame per 1000 Seconds)
		SIGNAL_CHECKNETRATE = 21; //return transfer-rate of net while seconds. LOWORD is data transfer rate, in M Bytes/S.
					  //HIWORD is rate of Frame-Lost, in number/10000 Frames


//-----sub-function defines for lEvent of WaitSignalEvent
		EVENT_FIELDHEADER = 1;    //field header
		EVENT_FRAMEHEADER = 2;    //frame header
		EVENT_ODDFIELD = 3;       //odd field come
		EVENT_EVENFIELD	= 4;      //even field come
		EVENT_EXTTRIGGER = 5;     //extern trigger come,
									            //(HIWORD(lEvent) is pole)



    STATICVXD = 1;
    INSTNTDRV = 2;
    ALLOCBUFFER = 3;
    MEMBLOCKSIZE = 4;
    MEMBLOCKCOUNT = 5;
    UNREGISTER = 6;

//-----defines for several target we can support

    DLBUFFER = TARGET(1);	  //Buffer(physical) allocated from host memory
    DLVIDEO = TARGET(0); 	  //Video source input to the board
    DLSCREEN = TARGET(-1);	  //Screen supported by VGA
    DLFRAME = TARGET(-2);	  //Frame buffer on the board
    DLMONITOR = TARGET(-3);	  //Monitor supported by (D/A) TV standard
    DLGRAPH	= TARGET(-4);	  //Graph frame on the board


    SEQFILE = $5153;	//SQ
    BMPFILE = $4d42;	//BM
    JPGFILE = $504A;	//JP
    RAWFILE = $5752;    //RW
    JHIFILE = $484A;	//JH

    BLKHEADER = $4b42;	//BK
    BMPHEADER = $4d42;	//BM
    BUFHEADER = $4642;	//BF

    IPADDRESS =	$4A49;  //IP(J)
    MACADDRESS = $434d;	//MC

    //-----defines messages for user

    WM_CLOSEREPLAY = WM_USER+100;
    //send this message when close replay dlg

    WM_BEGINSEQPROC = WM_USER+101;
    //begin seq proc, wParam=hBaord
    WM_SEQPROGRESS = WM_USER+102;
    //seq in progress, wParam=hBaord, lParam=No. to
    WM_ENDSEQPROC = WM_USER+103;
    //end seq proc, wParam=hBaord

    WM_ASKWAITVERTICAL = WM_USER+104;
    //ask to wait next vertical blank


//-----sub-function defines for wParam of okBeginEncode and okBeginDecode
	CODE_JPEG = 1;			//use JPEGPARAM when to set, and use IMAGESIZE when to get
	CODE_MPEG2 = 2;			//use MPEG2HEADER for both
	CODE_MJPG = 3;			//use MJPGHEADER for both
	CODE_MPEG4 = 4;			//use MPEG4HEADER for both
	CODE_JPG2K = 5;			//use JPG2KHEADER for both


    DLPROGRAM = 1;
    VERSION = 2;
    PREFIX = 3;
    COMPANY = 4;
    TELFAX = 5;
    WEBEMAIL = 6;
    LANGUAGE = 7;

//-----defines wParam in okSetAudioParam
    AUDIO_RESETALL = 0;                 //reset all to sys default
    AUDIO_SAMPLEFRQ = 1;                //set sample rate (in unit of samples per second)
    AUDIO_SAMPLEBITS = 2;               //set bits per sample to capture, lParam=-2: just get current signal's bits
    AUDIO_INVOLUME = 3;                 //set audio input gain control
    AUDIO_CALLINTERVAL = 4;             //set min. interval times of callback
    AUDIO_SOURCECHAN = 5;               //LOWORD select channel number in one signal source, HOWORD select signal source number
    AUDIO_SOUNDCHAN = 6;                //LOWORD: set sound channel to capture, HIWORD: return channels supported with this signal
    					//b0:left(mono) channel,b1:right, b2:middle, b3:left-back, b4:right back, b5:subwoof,...
    AUDIO_SIGNALINFO = 7;               //just get signal infos, b0=1: signal exist,

    FULLCOPY =	0;		                  //copy full text region into target
    FULLXOR = 1;		                  //xor full text region and target
    COPYFONT = 2;		                  //just copy fonts strokes to target
    XORFONT = 3;		                  //just xor fonts strokes and target

    NONE = 0;                           //
//-----defines wParam in okSetStreamParam

    STREAM_RESETALL = 0;                //reset all to sys default
    STREAM_RESOLUTION = 1;              //Sample resolution, 0=D1(default),1=2/3D1,2=1/2D1,3=SIF, for c20b
    STREAM_BITRATEMODE = 2;             //Bit Rate mode, =0: CBR(Constant), others: VBR(Variable BR)(default=3000), for c20b
    STREAM_MAXBITRATE = 3;              //Max Bit Rate, it is BR for CBR, it is max BR for VBR(default=9000) (kb/s), for c20b
    STREAM_CALLINTERVAL = 4;            //callback after interval times

    STREAM_RECTSELECT =	5;              //0(default): take rect same as capture, 1:itself, independent, used in like rgb60c
    STREAM_RECTSOURCE =	5;              //discarded, same as above
    STREAM_SOURCERECT =	6;              //set independent rect of stream source (lParam=&rect), for rgb60c

    STREAM_PICKFRMRATE = 7;             //set rate to pick number of frame per 100 frames, 0(default): auto mode . for rgb60c/e, rgb61c_e
    STREAM_QUALITY = 8;                 //set quality factor, for rgb60c 10~100, =100: the best. 0(default) mean 50
    STREAM_MAXFILELEN =	9;              //Set a size limit of file's length (in MegaByte) for any file on either ntfs or fat32 file system
					//when great this size set it will create another new file (in format name-1.XXX, etc.).
					//If no limit size was specified, It will also re-create new file automatically for AVI file or on FAT32
					//when file size is great than 3.5G

    SERIAL_COMMINDEX =	0;              //current comm index to r/w, default value=0
    SERIAL_BAUTRATE = 1;                //comm baut rate,like 9600,1200...default=9600
    SERIAL_DATABITS = 2;                //data bits, like 8,9...default=8
    SERIAL_STOPBITS = 3;                //stop bits, 0=1, 1=1.5, 2=2, default=0
    SERIAL_PARITY = 4;                  //parity bit, 0:no, 1:odd,2:even, default=0

    MJPG_SKIP	=	$50494B53;	//SKIP
    MJPG_GINF	=	$464E4947;	//GINF

//-----sub-function defines for iEvent of SetEventCallback
    EVENT_TOCLOSEDEVICE = 1;	        //callack before close board(device)
    EVENT_NETCONNECTCHANGE = 2;	       //callack after net connect status changed

//------ okapi32 functions list -----------


//--1. basic routines--------------


//prolog and epilog
function okOpenBoard(var Index:MLONG):HWND;stdcall;external'okapi32.dll'; //okLockBoard
                		//open a Ok series board in specified index(0 based), return 0 if not found any
                		//if success, return a handle to control specified board
                		//if set index=-1, mean takes default index no. (default is 0 )
                		//if user not specified by 'Ok Device Manager' in Control Pannel)
                		//this index can be also a specified board type code, or ip address string
                		//this function will change iIndex to the true used index,
                		//if index input is -1 or type code}

function okOpenBoardEx(var iIndex:MLONG; hParBoard:HWND; lParam:Pointer):HWND;stdcall;external'okapi32.dll'; // 11/04/13
                		//this is expended function of okOpenBoard
                		//hParBoard is parent handle of new board to open, which usually be NULL
                		//if use this func open a handle with hParBoard, the handle should be closed before hParBoard be closed
                		//lParam now is not used, which should be NULL
                		//others are same as okOpenBoard above,

function okCloseBoard(hBoard:HWND):Boolean;stdcall;external'okapi32.dll'; //okCloseBoard
                		//Save current parameters and then unlock and close Ok board specified handle and

function  okCloseBoardEx(hBoard:HWND; dwSave:DWORD):Boolean;stdcall;external'okapi32.dll'; //okCloseBoardEx
                		//Unlock and close Ok board specified handle
                		//dwSave=1: same as okCloseBoard, first save all current parameter to attached device
                		//dwSave=0; not to save, just close board

function okGetLastError:Int32;stdcall;external'okapi32.dll';
                		//Get last error msg
function okGetDriverVer(lpString:LPSTR; iSize:Int32):Int32;stdcall;external'okapi32.dll';
                		//get version of current ok cards driver
                		//lpString return version char string (e.g "5.08"),  iSize is lpString' size

function okGetBufferSize(hBoard:HWND; lpLinear:Pointer; var dwSize:MWORD):MLONG;stdcall;external'okapi32.dll';
                		//get base address and size of pre-allocated buffer,
                		//if success return the max. frame num in which can be store according to current set
                		//else return false;
function okGetBufferAddr(hApi:HWND; lNoFrame:MLONG):Pointer;stdcall;external'okapi32.dll';
                		//get base address of specified frame No. in BUFFER
                		//if success return the linear base address
                		//else return false;

function okGetTargetInfo(hApi:HWND; tgt:TARGET; lNoFrame:MLONG; var wid:SHORT; var ht:SHORT; var stride:MLONG):Pointer;stdcall;external'okapi32.dll';
                		//get target info include base address, width, height and stride specified frame No.
                		//if success return the linear base address and other infos, else return false;}

function okGetTypeCode(hBoard:HWND;lpBoardName:LPSTR):Int32;stdcall;external'okapi32.dll';
                		//return type code and name of specified handle, the memory lpBoardName points must be big enough or be NULL
                		//lpBoardName==-3: return code of majmin, =-4: return index number in total;  =-5 return IPCode, =-6 return HI IP
                		//=-7: return HardVer; =-8: return Devce Type(0:PCI,PCI_E...,1:USB,..), =-10: return if LineScan Device

function okGetNetDevNumber(iTypeCode:Int32; lpNameString:LPSTR):Int32;stdcall;external'okapi32.dll';
                		//check and get number of ok net device by typcode or name
                		//iTypeCode is type code, lpNameString is name
                		//return 0, mean not net device, else return sequence number (based 1)
                		//


//set rect and capture
function okSetTargetRect(hBoard:HWND; tgt:TARGET; var lpTgtRect:TRect):MLONG;stdcall;external'okapi32.dll';
                		//set target (VIDEO, SCREEN, BUFFER, FRAME)capture to or from
                		//if Rect.right or .bottom) are -1 , they will be filled current value
                		//special note for target=BUFFER:
                		//if never set CAPTURE_BUFBLOCKSIZE, the block size(W,H) of buffer will be changed
                		//according to size of right x bottom of lpRect, else the size will not changed
                		//specail note 2 for hwnd:
                		// left=right mean use rect of SCREEN, left=1 & right=0 mean match real rect of hwwnd, else take its rect set
                		//if success return max frames this target can support, else return <=0

function okSetToWndRect(hBoard:HWND;hWnd:HWND):Int32;stdcall;external'okapi32.dll';
                		//set client rect of hwnd as screen rect


function okCaptureSingle(hBoard:HWND;Dest:TARGET;lStart:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//capture video source to target which can be BUFFER, SCREEN, FRAME, MONITOR
                		//start(o based).if success return 1, if failed return 0, if not support target -1
                		//when this function sent command to grabber, then return immediately not wait to finish.
                		//this function same as okCaptureTo(hBoard, Dest, wParam, 1);

function okCaptureActive(hBoard:HWND;Dest:TARGET;lStart:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//capture continuous active video to same position in target which can be BUFFER, SCREEN, FRAME, MONITOR
                		//start(o based).if success return 1, if failed return 0, if not support target -1
                		//when this function sent continuous command to grabber, then return immediately
                		//but note that some card like RGB30. when target is SCREEN, this function is a thread.
                		//this function same as okCaptureTo(hBoard, Dest, wParam, 0);

function okCaptureThread(hBoard:HWND;Dest:TARGET;lStart:MLONG;lParam:MLONG):HWND;stdcall;external'okapi32.dll';
                		//capture sequencely video to target which can be BUFFER, SCREEN, FRAME, MONITOR
                		//start(o based). lParam>0: number of frame to capture to,
                 		//if lParam > total frames in BUFER, it will loop in rewind mode(i%total)
                		//if lParam=-N mean it loop in buffer of N frame infinitely until call okStopCapture,
                		//when -1 mean loop in all buffer.
                		//return max num frame can be stored in the target if success,
                		// return 0 if failed(eg. format not matched). -1 not support target
                		//this call will create a thread to manage to capture sequencely then
                		//return immediately not wait to finish. This thread will callback if need
                		//this function same as okCaptureTo(hBoard, Dest, wParam, n);
                		//but it is not same, when n=1 this function is also a thread and still support callback

function okCaptureToScreen(hBoard:HWND):MLONG;stdcall;external'okapi32.dll';
                		//Start to capture to screen (video real-time display on screen) and return immediately
                		//this is just a special routine of okCaptureTo(hBoard,SCREEN,0,0)

function okCaptureTo(hBoard:HWND; Dest:TARGET; start:MLONG; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//capture video source to target which can be BUFFER, SCREEN, FRAME, MONITOR
                		//start(o based), lParam>0: number of frame to capture to, =0: cont. mode,
                 		//if lParam > total frames in BUFER, it will loop in rewind mode(i%total)
                		//if lParam=-1 mean it loop infinitely until call okStopCapture
                		//return max num frame can be stored in the target if success,
                		// return 0 if failed(eg. format not matched). -1 not support target
                		//this call will return immediately not wait to finish.
                		//This function is not recomended to use for new user

function okPlaybackFrom(hBoard:HWND; src:TARGET; start:MLONG; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//playback on monitor from target which can be BUFFER, FRAME
                		//start(o based), lParam>0: number of frame to capture to, =0: cont. mode
                		//if lParam > total frames in BUFER, it will loop in rewind mode (i%total)
                		//if lParam=-1 mean it loop infinitely until call okStopCapture
                		//return max num frame be stored in the target if success,
                		//return 0 if wrong. -1 not support target
                		//this call will return immediately not wait to finish.
                		//

//get status and stop capture
function okGetCaptureStatus(hBoard:HWND; bWait:Boolean):MLONG;stdcall;external'okapi32.dll';
                		//query capturing status, if bWait then wait to finish capturing, else return immediately.
                		//return 0 if finished, if cont. mode capturing return target capture to
                		//(which include SCREEN -1, FRAME -2, MONITOR -3)
                		//if capturing to/from BUFFER or file, return the frame No.(1 based) being capturing

function okGetLineReady(hBoard:HWND; var iCurrFrameNo:MLONG; dwRes:MWORD):MLONG;stdcall;external'okapi32.dll';
                		//get current line number captured already (supported only by LineScan Capture cards)
                		//get current line number already captured.
                		//iCurrFrameNo returned is always total frame number(based 1) already captured, 0 mean no frame finished yet.
                		//return line number(based 1) already captured in current frame, 0 mean no line fnished in current frame.
                		//dwRes is reserved, should be NULL.

function okStopCapture(hBoard:HWND):MLONG;stdcall;external'okapi32.dll';
                		//Stop capturing to or playback from SCREEN, BUFFER or other targets
                		//return target just captured to or from.
                		//if capturing to/from BUFFER or file, return the total frame No.(1 based) being capturing
                		//it may be not stoped immediatly for sequence capture after returned

function okStopCaptureEx(hBoard:HWND; dwCmdCode:DWORD; lParam:Longint):MLONG;stdcall;external'okapi32.dll';
                                //It's a extend func of okStopCapture,


function okGetSeqCapture(hBoard:HWND; start:MLONG; count:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//get current frame no. of sequence capturing to buffer
                		//start: set buffer no. to use, effecting only count==0
                		//count: count no. to catpure, start from count=0
                		//return frame no finished

//capture by to /from
function okCaptureByBuffer(hBoard:HWND; dest:TARGET; start:MLONG; num:MLONG):HWND;stdcall;external'okapi32.dll';
                		//capture sequence images to dest by way of two frame buffers (in BUFFER),
                		//the frame size and format is taken as same as current config of BUFFER
                		//if dest is file name which can be .seq or .bmp (will generate multi bmp files)
                		//dest can be also a user memory pointer or a BLOCKINFO pointer (with user memory pointer)
                		//retrun true immediately if success. num should be great than 0

function okCaptureByBufferEx(hBoard:HWND; fileset:MLONG; dest:TARGET; start:MLONG; num:MLONG):MLONG;stdcall;external'okapi32.dll';
                		// all are same as okCaptureByBuffer except for fileset which is quality when to jpg file

function okPlaybackByBuffer(hBoard:HWND; src:TARGET; start:MLONG; num:MLONG):HWND;stdcall;external'okapi32.dll';
                		//playback sequence images on monitor from src by way of two frame buffers (in BUFFER)
                		//the size and format of BUFFER will be changed to same as src
                		//src can be a file name which may be .seq or .bmp (first orderd bmp files)
                		//src can be also a BLOCKINFO pointer (with infos of user memory pointer,size and format)
                		//if src is just user memory pointer, this function will think its block size and format
                		//are same as current config of BUFFER (in this case can not support loop function).
                		//retrun true immediately if success
                		//if num is great than the true frame number in src, it will loop back
                		//if num=-1 mean it will loop infinitely until call okStopCapture}

//set and get params
function okSetVideoParam(hBoard:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//----set video param sub-function defines
                		//set video param and return previous param;
                		//if input lParam=-1, just return previous param
                		//if not support return -1, if error return -2

function okSetCaptureParam(hBoard:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set capture param and return previous param;
                		//if input lParam=-1, just return previous param
                		//if not support return -1, if error return -2

function okSetDeviceParam(hBoard:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set (net) device param and return param;
                		//wParam is a item to set,
                		//lParam can be single param to set, or in/out pointer, or structure pointer
                		//if success return 1, else return 0


//transfer and convert rect
function okReadPixel(hBoard:HWND; src:TARGET; start:MLONG; x:SHORT; y:SHORT):Int32;stdcall;external'okapi32.dll';
                		//read value of one pixel specified (x,y) in frame start of src (SCREEN, BUFFER, FRAME...)
                		//return is this pixel value, it may be with bits 8,16,24,or 32 depend on the src's format

function okWritePixel(hBoard:HWND; tgt:TARGET; start:MLONG; x:SHORT; y:SHORT; lValue:Int32):Int32;stdcall;external'okapi32.dll';
                		//write value into specified (x,y) in the frame start of tgt (SCREEN, BUFFER, FRAME...)

function okSetConvertParam(hBoard:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set convert param for for function okConvertRect
                		//if not support return -1, if error return -2

function okReadRect(hBoard:HWND; src:TARGET; start:MLONG; lpBuf:Pointer):Int32;stdcall;external'okapi32.dll';
                		//read data into lpBuf from rect(set previous) in frame start of dst (SCREEN, BUFFER, FRAME)
                		//the data in lpBuf stored in way row by row
                		//if src not supported return -1, if failed return 0,
                		//return -1 if not support, return 0 failed,
                		//if success return data length read in byte
                		//if lpBuf=NULL, just return data length to read

function okWriteRect(hBoard:HWND; dst:TARGET; start:MLONG; lpBuf:Pointer):Int32;stdcall;external'okapi32.dll';
                		//write data in lpBuf to rect(set previous) of dst (SCREEN, BUFFER, FRAME)
                		//the data in lpBuf stored in way row by row
                		//return -1 if not support, return 0 failed,
                		//if success return data length written in byte

function okReadRectEx(hBoard:HWND; src:TARGET; start:MLONG; lpBuf:Pointer; lParam:Int32):Int32;stdcall;external'okapi32.dll';
                		//read data into lpBuf from rect(set previous) in frame start of dst (SCREEN, BUFFER, FRAME)
                		//the data in lpBuf stored in way row by row
                		//if src not supported return -1, if failed return 0,
                		//return -1 if not support, return 0 failed,
                		//if success return data length read in byte
                		//if lpBuf=NULL, just return data length to read
                		//LOWORD(lParam）is form code for bits of lpBuf (e.g.：FORM_GRAY8），if it is 0 mean: as same as src
                                //HIWORD(LParam) is the mode of taking channels. mode=0 take all, =1 red, =2 green, =3 blue;

function okWriteRectEx(hBoard:HWND; dst:TARGET; start:MLONG; lpBuf:Pointer; lParam:Int32):Int32;stdcall;external'okapi32.dll';
                		//write data in lpBuf to rect(set previous) of dst (SCREEN, BUFFER, FRAME)
                		//the data in lpBuf stored in way row by row
                		//return -1 if not support, return 0 failed,
                		//if success return data length written in byte
                		//LOWORD(lParam）is form code for bits of lpBuf (e.g.：FORM_GRAY8），if it is 0 mean: as same as dst
                                //HIWORD(LParam) is the mode of taking channels. mode=0 take all, =1 red, =2 green, =3 blue;

function okTransferRect(hBoard:HWND; dest:TARGET; iFirst:MLONG; src:TARGET; iStart:MLONG; lNum:MLONG):Int32;stdcall;external'okapi32.dll';
                		//transfer source rect to dest rect (here target can be SCREEN, BUFFER, FRAME, also BLOCKINFO point to user memory)
                		//if total in dest or src less than lNum, it will rewind to begin then continue
                		//this function transfer in format of src, that means it don't convert pixel bits if dst and src are not same
                		//if src or dst not supported return -1, if failed return 0,
                		//if success return data length of one block image in byte}

function okConvertRect(hBoard:HWND; dst:TARGET; first:MLONG; src:TARGET; start:MLONG; no:MLONG):Int32;stdcall;external'okapi32.dll';
                		//transfer source rect to dest rect (here target can be SCREEN, BUFFER, FRAME, also BLOCKINFO point to user memory)
                		//if total in dest or src < lNum, it will rewind to begin then continue
                		//this function convert to pixel foramt of dst if dst has not same bits format as src
                		//if src or dst not supported return -1, if failed return 0,
                		//if success return image size of one block in pixel

function okConvertRectEx(hDstBoard:HWND; dst:TARGET; first:MLONG; hSrcBoard:HWND; src:TARGET; start:MLONG; no:MLONG):Int32;stdcall;external'okapi32.dll';
                		//same as the above function okConvertRect except with src handle

//get and put signals
function okGetSignalParam(hBoard:HWND; dlwParam:Int32):Int32;stdcall;external'okapi32.dll';
                		//Get specified param of video signal source
                		//if not support return -1, if error return -2, else return param

function okWaitSignalEvent(hBoard:HWND; dlwParam:Int32; lMilliSecond:MLONG):Int32;stdcall;external'okapi32.dll';
                		//Wait specified signal come
                		//lMilliSecond is time-out time in milliseconds for to wait
                		//if lMilliSecond is zero, the function returns current state immediately
                		//if lMilliSecond is INFINITE(-1) wait forever until event come
                		//return -1 not support, 0 speicfied signal not come, 1 come

function okPutSignalParam(hBoard:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set param to output specified signal to some other device
                		//if not support return -1, if error return -2,

//treat callback functions
function okSetSeqProcWnd(hBoard:HWND; hwndMain:HWND):Boolean;stdcall;external'okapi32.dll';
                		//set proc hwnd for receive message about sequence capture}

function okSetSeqCallback(hBoard:HWND;BeginProc:TFarProc;SeqProc:TFarProc;EndProc:TFarProc):Boolean;stdcall;external'okapi32.dll';
                		//set callback function for multi-frame capturing function
                		//(which are okCaptureTo, okCaptureFrom,okCaptureToFile, okCaptureFromFile)
                		//see follow

function okSetUserData(hBoard:HWND; lUserData:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set or get user data to or from hBoard.
                		//when lUserData==-1, set nothing, else set value of lUserData to hBoard
                		//return lUserData preset


//function BeginProc(hBoard:HWND):Boolean;stdcall; //user defined callback function
                		//callback this function before to capture
//function SeqProc(hBoard:HWND; No:MLONG):Boolean;stdcall; //user defined callback function
                		// callback this function after finish capturing one frame
                		// No is the number(0 based) frame just finished or being playbacked.
//function EndProc(hBoard:HWND):Boolean;stdcall; //user defined callback function
                		// callback this function after end capturing

//function EventProc(hBoard:HWND; dwReserved:MWORD):Boolean;stdcall; //user defined callback function for okSetEventCallback

function okSetEventCallback(hBoard:HWND; iEvent:INT32; EventProc:TFarProc):Boolean;stdcall;external'okapi32.dll';
                		//set some event callback proc, which will be callback before or after this event

function okSetCloseCallback(hBoard:HWND; CloseProc:TFarProc):Boolean;stdcall;external'okapi32.dll';
                		//set callback proc of okCloseBoard, which will be callback before it close board
                		//same as EVENT_TOCLOSEDEVICE

//function CloseProc(hBoard:HWND; dwReserved:DWORD):Boolean;stdcall; //user defined callback function for okCloseBoard

//save and load files
function okSaveImageFile(hBoard:HWND; szFileName:LPSTR; first:MLONG; target:TARGET; start:MLONG; num:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//here target can be BUFFER, SCREEN, FRAME or user buffer pointor
                		//1.if ext name=".bmp", "raw", "jpg", thus one file with single frame, then:
                		//create num new file and than save one frame in each file begin from start position of target as bmp file
                		//when argument num is great than 1, a: File name will be appended 000 and auto-plus-1 if without digit in
                		//szFileName; b: File name will be auto-plus-1 in parts of digits if we find digit in szFileName(like aa1000.bmp);
                		//
                		//2.if ext name=".seq","avi", thus one file with multi-frames (we call those file as sequences file), then
                		//save num frame from (start) in target into (first) frame pos in seq(sequence) file in sequencely.
                		//if the file already exist the function will not delete it, that mean old contents in the file will be kept.
                		//So if you want create a new seq file with a existed file name you must delete before this call .
                		//for sequences file, better we use stream way called "beg,con,end" when we save multi-frames into this one file.
                		//to create file just call this func whith szFileName appended ",beg", and to finish file just with szFileName
                		//appended ",end", to save each frame data one by one just call it with szFileName appended ",con".
                		//in this way argument first will be ignored

function okLoadImageFile(hBoard:HWND; szFileName:LPSTR; first:MLONG; target:TARGET; start:MLONG; num:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//here target can be BUFFER, SCREEN, FRAME or user buffer pointor. here first and start both are based 0
                		//1.if ext name=".bmp":
                		//load one frame into start position of target from bmp file
                		//
                		//2.if ext name=".seq":
                		//load no frame into (start) in target from (first) frame pos in seq(sequence) file in sequencely.
                		//return total number for sequence format file (like .seq, .avi, ...), total data length for single format file
                		//not load image data when num=0

function okGetCurrImageInfo(hBoard:HWND; lpImgFrmInfo:MLONG; lSize:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//used for okLoadImageFile
                		//get extra infos of current image which is last loaded by okLoadImageFile
                		//lpImgFrmInfo is structure (see EXTRAFRMINFO) stored extra info, lSize should be size of the structure
                		//return 1 if lpImgFrmInfo none 0, else return 0;


//load and save config files with all parameters
function okSaveConfigFile(hBoard:HWND; szFileName:LPSTR):Boolean;stdcall;external'okapi32.dll';
                		//save all current parameters(include stream' params after 11/07/11 ver 4.0 )  set to specified config file
                		//(*.okf: full params; *.oks:sample params; *.oko: output params),

function okLoadConfigFile(hBoard:HWND; szFileName:LPSTR):Boolean;stdcall;external'okapi32.dll';
                		//load some kind of specified config file to set current all paramters
                		//

//load and save flat field model
function okSaveFlatModelFile(hApi:HWND; szFile:LPSTR):Boolean;stdcall;external'okapi32.dll';
                		//save flat model from buf0,and 1 to szFile
                		//ext name must be ".fla"

function okLoadFlatModelFile(hApi:HWND; szFile:LPSTR):Boolean;stdcall;external'okapi32.dll';
                		//load flat model file to buf0,and 1, and then set it to inner model
                		//ext name must be ".fla"

//--2. special routines supported by some cards--------------

//---overlay mask:
function okEnableMask(hBoard:HWND; bMask:Smallint):Int32;stdcall;external'okapi32.dll';
                                //bMask因为可能直接输入2或-1故不能声明为Boolean
                		//0: disable mask; 1: positive mask, 2: negative mask
                		//positive: 0 for win clients visible, 1 video visible
                		//negative: 0 for video visible,  1 for win client (graph) visible
                		//if bMask=-1 actually not set just get status previous set
                		//return last mask status,

function okSetMaskRect(hBoard:HWND; var lpRect:TRect; lpMask:LPSTR):Int32;stdcall;external'okapi32.dll';
                                //lpMask因为可能直接输入0或1故不能声明为var lpMask BYTE
                		//Set mask rect(lpRect is relative to lpDstRect in SetScreenRect or
                		//SetBufferRect, lpMask is mask code (in byte 0 or 1). one byte for one pixel
                		//if lpMask==1, set all rect region in lpRect video visible
                		//if lpMask==0, set all rect region in lpRect video unvisible
                		//return base linear address of inner mask bit

//---set out LUT:
function okFillOutLUT(hBoard:HWND;  bLUT:Pointer; start:Int32; num:Int32):Int32;stdcall;external'okapi32.dll';
                		//fill specified playback out LUT.
                		//bLut stored values to fill, (r0,g0,b0, r1,g1,b1 ...)
                		//start: offset pos in LUT(based 0), num: num items to fill

//set input LUT:
function okFillInputLUT(hBoard:HWND; bLUT:Pointer; start:Int32; num:Int32):Int32;stdcall;external'okapi32.dll';
                		//fill specified input LUT.
                		//bLut stored values to fill, (r0,g0,b0, r1,g1,b1 ...)
                		//start: offset pos in LUT(based 0), num: num items to fill

function okCaptureSequence(hBoard:HWND; lStart:MLONG; lNoFrame:MLONG):Int32;stdcall;external'okapi32.dll';
                		//capture sequence to BUFFER by way of Interrupt Service Routine
                		//Note: Only M10 series, M20H,M40, M60, M30, M70 and RGB20 support this way
                		//wParam=start(o based). lParam>0: number of frame to capture to,
                 		//if lParam > total frames in BUFER, it will loop in rewind mode(i%total)
                		//when -1 mean loop in all buffer. infinitely until call okStopCapture,
                		//return max num frame can be stored in the target in this way if success,
                		// return 0 if failed(eg. format not matched). -1 not support target
                		//this call will start a Interrupt Service Routine to manage to capture sequencely then
                		//return immediately not wait to finish. This routine not support callback

function okPlaybackSequence(hBoard:HWND; lStart:MLONG; lNoFrame:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//playback on monitor from BUFFER
                		//start(0 based), lNoFrame>0: number of frame to capture to,
                		//if lParam > total frames in BUFER, it will loop in rewind mode (i%total)
                		//if lParam=-1 mean it loop infinitely until call okStopCapture
                		//return max num frame be stored in the target if success,
                		//return 0 if wrong. -1 not support
                		//this call will start a Interrupt Service Routine to manage to playback sequencely then
                		//return immediately not wait to finish. This routine not support callback
                		//

//
function okSetDriverParam(lWhich:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//lWhich defined as the follow

//-- set pre-allocate buffer size in k byte
function okSetAllocBuffer(dwSize:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set the new size to preallocate in k bytes,
                		//if new size is not same as current,
                		//then the functuion will restart the window system

function okSetStaticVxD(lMode:Int32):Boolean;stdcall;external'okapi32.dll';
                		//lMode=0: check if static vxd registered.
                		//=1: create static vxd register
                		//=2: delete static vxd register

function okSetNTDriver(bCmd:Int32):Int32;stdcall;external'okapi32.dll';
                		//bCmd=0: check if nt driver installed.
                		//=1: install nt driver
                		//=2: remove nt driver

function okUnRegister(dwCmd:DWORD):Boolean;stdcall;external'okapi32.dll';
                		//uninstall all registered and generated infos

function okGetProgramInfo(iItem:Int32; lpString:LPSTR; iSize:Int32):Int32;stdcall;external'okapi32.dll';
                		//get program info

function okSetLangResource(langcode:Int32):Int32;stdcall;external'okapi32.dll'; //1252 for English, 936 for Simple Chinese

//--3. multi cards, channels, memories --------------

//---multi cards access--------
function okGetImageDevice(var lpOkDevInfo:LPOKDEVTYPE; lParam:MLONG):Int32;stdcall;external'okapi32.dll';
                		//Query all Ok series Image devices available in PCI bus, USB, GigE ... return total number
                		//lParam is pointer which is input/ouput. Input b0:1, re-check, b1:1, include net devices
                		//Output: return flag include net devices from config set by Ok Image Manager
function okGetSlotBoard(var lpOkInfo:LPBOARDTYPE):SHORT;stdcall;external'okapi32.dll';
                		//Query all Ok boards available in PCI bus, return total number
function okGetBoardIndex(var szBoardName:char; iNo:SHORT):SHORT;stdcall;external'okapi32.dll';
                		//Get index (start 0) of specified board name string (it can also be typcode string)
                		// and order in same name (start 0) from current ok image device list.
                		//return -1 if no this specified ok board
function okGetBoardName(lIndex:SHORT; szBoardName:LPSTR):Int32;stdcall;external'okapi32.dll';
                		//get the board code and name of the specified index
                		//return the type code if success else return 0 if no card

//multi cards capture
function okMulCaptureTo(var lphBaord:HWND;Dest:TARGET; start:MLONG; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//control multi boards to capture to target simultaneously, lphBaord are pointer of hBoard of multi board
                		//it must be end in zero.
                		//other functions are same as okCaptureByBuffer

function okMulCaptureByBuffer(var lphBaord:HWND;tgt:TARGET; start:MLONG; num:MLONG):HWND;stdcall;external'okapi32.dll';
                		//control multi boards to capture by buffer simultaneously, lphBaord are pointer of hBoard of multi board
                		//it must be end in zero.
                		//other functions are same as okCaptureByBuffer

//multi channels:
function okLoadInitParam(hBoard:HWND; iChannNo:SHORT):Boolean;stdcall;external'okapi32.dll';
                		//load specified chann(based 1)  (and as current chann.)of initial params
function okSaveInitParam(hBoard:HWND; iChannNo:SHORT):Boolean;stdcall;external'okapi32.dll';
                		//save current init param to specified chann(based 1) (and as current chann.)

//get and lock buffer
function okGetAvailBuffer(var lpLinear:Pointer; var dwSize:MWORD):MLONG;stdcall;external'okapi32.dll';
                		//Get free meomery buffers pre-allocated .
                		//call it when user hope to access buffer directly or lock for one board
function okLockBuffer(hBoard:HWND; dwSizeByte:MWORD; var lpBasLinear:Pointer):MLONG;stdcall;external'okapi32.dll';
                		//Lock speicfiled size meomery buffers, then other handle can not use
function okUnlockAllBuffer:Boolean;stdcall;external'okapi32.dll';
                		//Unlock all buffer

//Mem Block Buffer appended to BUFFER
function okApplyMemBlock(dwBlockSize:DWORD; dwBlockNo:DWORD):Int32;stdcall;external'okapi32.dll';
                		//apply mem block used as buffer appended to BUFFER
                		//return the number of blocks allocated actually

function okFreeMemBlock:Boolean;stdcall;external'okapi32.dll';
                		//release appended MemBlock by okApplyMemBlock

function okGetMemBlock(hApi:HWND; var dwEachSize:DWORD; var dwBlockNo:DWORD):Int32;stdcall;external'okapi32.dll';
                		//get the number of MemBlock and size per block applied by okApplyMemBlock
                		//and return the number can be as buffer as to cureent set size of BUFFER

function okLockMemBlock(hBoard:HWND; lBlockNo:DWORD):Int32;stdcall;external'okapi32.dll';
                		//lock number of MemBlock to specified handle

function okUnlockMemBlock:Boolean;stdcall;external'okapi32.dll';
                		//unlcok all locked MemBlock

//--4. apps utilities-----------------

//apps setup dialog
function okOpenSetParamDlg(hBoard:HWND;hParentWnd:HWND):Boolean;stdcall;external'okapi32.dll';
                	//dialog to setup video param
function okOpenSeqCaptureDlg(hBoard:HWND; hParentWnd:HWND):Boolean;stdcall;external'okapi32.dll';
                	//dialog to capture sequence image

function okOpenReplayDlg(hBoard:HWND; hWnd:HWND; src:TARGET; total:MLONG):LPDIBINFO;stdcall;external'okapi32.dll';
                	//open modeless dialog to replay sequence images(in BUFFER, USERBUF or seq file) on SCREEN or MONITOR

function okOpenReplayDlgEx(hBoard:HWND;hWnd:HWND;src:TARGET; total:MLONG;var lpbi:TBITMAPINFOHEADER; var lpdib:BYTE):HWND;stdcall;external'okapi32.dll';
                	//open modeless dialog to replay sequence images(in BUFFER, USERBUF or seq file) on SCREEN or MONITOR

function okAutoAdjustBright(hBoard:HWND; var lpRect:TRect; dwRes:Pointer):Int32;stdcall;external'okapi32.dll';
                		//Auto adjust image to the best seeing by setting gain, brightness, contrast and saturation if they can be set,
                		//lpRect is AOI in current BUFFER to measure, it must less than rect of BUFFER and great than 8X8
                		//Take whole rect of BUFFER if lpRect==NULL
                		//dwRes==0, now not used.
                		//return mean gray value between 0 ~ 255, if success.

function okAutoSetCapRect(hBoard:HWND; Width:Int32; Height:Int32):Int32;stdcall;external'okapi32.dll';
                		//auto set all param to adapt source video

function okOpenSetLUTDlg(hBoard:HWND; wnd:HWND; lpLUT:Pointer):Boolean;stdcall;external'okapi32.dll';
                		//dialog to set LUT of input and output if supported by current card
                		//lpLUT is buffer to store lut value set by this routine, when press OK button
                		//


//-------
function okUnifyFields(hBoard:HWND; tgt:TARGET; start:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//unify odd and even two fields which have different intensive brightness
                		//
function okDiffusionFilter(hBoard:HWND; tgt:TARGET; start:MLONG; nLoop:SHORT):Int32;stdcall;external'okapi32.dll';
                		//remove noise filter by diffusion method. nLoop is loop times, recommend it be 2
                		//return -1 when not support (not support virtual card)

function okGuassFilter(hBoard:HWND; tgt:TARGET; start:MLONG):Int32;stdcall;external'okapi32.dll';
                		//remove noise filter by guass method
                		//return -1 when not support (not support virtual card)

function okSharpFilter(hBoard:HWND; tgt:TARGET; start:MLONG; iClass:SHORT):Int32;stdcall;external'okapi32.dll';
                		//image sharper by edge enhance filter, iClass = 1~4 valid, 1: min. sharper, 4: max sharper
                		//return -1 when not support (not support virtual card)

function okGetFocusMeasure(hBoard:HWND; tgt:TARGET;  start:MLONG; var lpRect:TRect; iMethod:SHORT; iPreDegree:SHORT):Single;stdcall;external'okapi32.dll';
                		//lpRect is rect to measure for fucus
                		//which method, iMethod=0: deff, =1: robert, =2: 4X Laplacian, =3: 8X laplacian, =4: brenner
                		//pre-process degree, iPreDegree=0: no pre-filter, =1: 3x3 cross median, =2: 3x3 squr median, =3: 5x5 squr medain, =4: 7x7 squr median
                		//return mean measure value for focusness, more big more focus

function okMultiFrmMean(hBoard:HWND; tgt:TARGET; start:MLONG; number:MLONG):Int32;stdcall;external'okapi32.dll';
                		//acummulate number frame from start then take mean and place to start
                		//return -1 when not support


function okTakeRectMean(hBoard:HWND; tgt:TARGET; var lpRect:TRect; start:MLONG; iMode:SHORT):Int32;stdcall;external'okapi32.dll';
                		//calculate and return gray mean of rect specified
                		//if lpRect==NULL it mean whole rect of target
                		//return mean gray value

function okEvaluateHistogram(hBoard:HWND; tgt:TARGET; var lpRect:TRect; start:MLONG; var lpHist:DWORD):Int32;stdcall;external'okapi32.dll';
                		//evaluate histogram of rect specified
                		//if lpRect==NULL it mean whole rect of target
                		//lpHist points memery allocated by caller and its size must be great than number of gray level for TARGET
                		//for color it store data of b,g,r seperately
                		//if success LOWORD is number of bis(i.e. 8,10,16...), HIWORD is bits number of channels(i.e. 1 or 3) in return value

function okGetLinExtenMaplut(var lpHist:DWORD; iNumBits:SHORT; iNumChann:SHORT; iIntensity:SHORT; var lpwLUT:WORD):Int32;stdcall;external'okapi32.dll';
                		//get map lut of linear extending according to lpHist input
                		//lpHist points to histogram of one image, iNumBits and iNumChannis are bits and color channles of the image
                		//iIntensity is intensity (0: no change, 10:recomended value, ) to fullfill extending transfer
                		//lpwLUT is memory allocated by caller, in which the maplut are stored when return sucessful

function okGetHistEquaMaplut(var lpHist:DWORD; iNumBits:SHORT; iNumChann:SHORT; var lpwLUT:WORD):Int32;stdcall;external'okapi32.dll';
                		//get map lut of histaogram equalizing according to lpHist input
                		//lpHist points to histogram of one image, iNumBits and iNumChannis are bits and color channles of the image
                		//lpwLUT is memory allocated by caller, in which the maplut are stored when return sucessful



//text and graphics
function okSetTextTo(hBoard:HWND; tgt:TARGET; var lpRect:TRect; var lfLogFont:LOGFONT; var textMode:SETTEXTMODE; lpString:LPSTR; lLength:Int32):Boolean;stdcall;external'okapi32.dll';
                		//set text into the image of specified target
                		//target can be SCREEN, BUFFER, FRAME, also BLOCKINFO
                		//lpRect: just use its (left,top) to points start posision
                		//lfLogFont: windows font definition, see window's document
                		//textMode: specify forecolor, backcolor and set mode
                		//lpString, lLength: text string and it's length

function okDrawLineTo(hBoard:HWND; target:TARGET; lStart:MLONG; ptS:TPoint; ptE:TPoint; iForeColor:Int32):Int32;stdcall;external'okapi32.dll';
                		//draw a straight line into specified target
                		//target can be SCREEN, BUFFER, FRAME, also BLOCKINFO
                		//ptS, ptE: specify start and end point
                		//iForeColor: draw value on to target
                		//return the pixel count of line

function okDrawEllipsTo(hBoard:HWND; tgt:TARGET; lStart:MLONG; var lpRect:TRECT; iForeColor:Int32):Int32;stdcall;external'okapi32.dll';
                		//draw a ellips into specified target
                		//target can be SCREEN, BUFFER, FRAME, also BLOCKINFO
                		//lpRect: specify the rect region of expected ellips
                		//iForeColor: draw value on to target
                		//return the pixel count of ellips

function okFillCircleTo(hBoard:HWND; tgt:TARGET; lStart:MLONG; var lpRect:TRect; lForColor:Int32; iMode:Int32):Int32;stdcall;external'okapi32.dll';
                		//fill inside or outside of circle(or ellipse) area specified by lpRect
                		//target can be GRAPH, SCREEN, BUFFER, FRAME, also BLOCKINFO
                		//lpRect specify circle area, and circle's diameter take rect's max direction
                		//lForColor is the value to fill.
                		//iMode: b0=0: mean to fill value to outside area of circle; =1: to fill inside
                		//b1=0; fill circle area; =1: fill ellipse area

function okCreateDCBitmap(hBoard:HWND; tgt:TARGET; var hDCBitmap:HWND):HWND;stdcall;external'okapi32.dll';
                		//create a memory DC compatible with windows's GDI, draw graphic and text etc. with GDI functions
                		//target can be SCREEN, BUFFER, FRAME, also BLOCKINFO
                		//hDCBitmap: return a handle with which we can map the graphics on the memory DC
                		//to our target.
                		//return the memory DC with which you can use windows"s GDI functions

function okMapDCBitmapTo(hDCBitmap:HWND; lStart:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//map the graphics of memory DC created by okCreateDCBitmap into specified target
                		//hDCBitmap: the handle created by okCreateDCBitmap

function okFreeDCBitmap(hDCBitmap:HWND):Boolean;stdcall;external'okapi32.dll';
                		//free the allocated resource by okCreateDCBitmap
                		//hDCBitmap: the handle created by okCreateDCBitmap

function okWaitVerticalSync(hBoard:HWND; bHeader:Boolean):Boolean;stdcall;external'okapi32.dll';
                		//wait for verticl blank.
                		//bHeader=0, mean wait for begin of vertical, =1, mean wait for end.


//encode and decode
function okBeginEncode(hBoard:HWND; wCodeWay:DWORD; lParam:MLONG):HWND;stdcall;external'okapi32.dll';
                		//start to encode images. wCodeWay is JPEG or other compress,
                                //lpImageInfo is address of  preset parameters like size to encode
                		//return a handle of encoder if sucessful, else  return 0
function okEncodeImage(hCoder:HWND; src:TARGET; start:MLONG; lpData:Pointer; maxlen:MLONG):Int32;stdcall;external'okapi32.dll';
                		//encode one frame image . src is source like BUFFER, SCREEN, FRAME and BLOCK.
                		//lpData to store coded data,  maxlen is maximum length of lpCodedData
                		//return the length coded data
function  okEndEncode(hCoder:HWND):Int32;stdcall;external'okapi32.dll';
                		//end encode and release resources of encoder

function okBeginDecode(hBoard:HWND; wCodeWay:DWORD; lpData:Pointer; lpImageInfo:MLONG):HWND;stdcall;external'okapi32.dll';
                		//start to decode images. wCodeWay is CODE_JPEG or other compress,
                		//lpData is current start pos of coded data,
                		//lpImageInfo will return image info like size, no return when it is NULL
                		//return a handle of decoder if sucessful, else  return 0
function okDecodeImage(hCoder:HWND; lpData:Pointer; var length:MLONG; target:TARGET; start:MLONG):Int32;stdcall;external'okapi32.dll';
                		//decode coded data to image.
                		//lpData is pointer with coded data
                		//length is input length of coded data, it also output length of real used data
                		//target is aim to decode, like BUFFER, SCREEN, FRAME,BLOCK or memory pointer
                		//start is pos of specified target
                		//return TRUE if one image finished, else return 0
function okEndDecode(hCoder:HWND):Int32;stdcall;external'okapi32.dll';
                		//end decoder and release resources of decoder

//protect
function okReadProtCode(hBoard:HWND; iIndex:SHORT):Int32;stdcall;external'okapi32.dll';

function okWriteProtCode(hBoard:HWND; iIndex:SHORT; code:Int32):Int32;stdcall;external'okapi32.dll';

//--5. audio section routines--------------

//prolog and epilog
function okOpenAudio(hBoard:HWND; lParam:MLONG):HWND;stdcall;external'okapi32.dll';
                		//open audio device owned by the video capture board
                		//hBoard is handle of image board, lParam reserved argument normally must be set to 0
                		//when b0 of lParam =1 mean just check if it support audio
                		//return handle of the audio device

function okCloseAudio(hAudio:HWND):Boolean;stdcall;external'okapi32.dll';
                		//close audio device

//capture and stop
function okCaptureAudio(hAudio:HWND; target:TARGET; lpfnUserProc:TFarProc; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//start to capture audio data, target can be BUFFER(audio data buffer) or file name
                		//lpfnUserProc is callback function pointer, it must be NULL if not using callback
                		// lParam reserved argument must be set to 0
                		//return the maximum times in miliseconds the inner audio data memory can be stored for

function WriteAudioProc(hAudio:HWND; var lpAudBuf:BYTE; length:Int32):Boolean;stdcall;external'okapi32.dll';
                		//this callback function must written as the above protype by user
                		//call this function when there are enough audio data (the length in byte)
                		//call this function when capture ended with argument length=0;

function okStopCaptureAudio(hAudio:HWND):Boolean;stdcall;external'okapi32.dll';
                		//stop capturing audio data
                		//return total length of read out by okReadAudioData

//set and get audio
function okSetAudioParam(hAudio:HWND; wParam:Int32; lParam:Int32):Int32;stdcall;external'okapi32.dll';
                		//set the parameters to sample audio,  wParam see above defines
                		//return the new set value if success
                		//if not support return -1, if error return -2
                		//if input lParam=-1, just return previous param

function okReadAudioData(hAudio:HWND; var lpAudioBuf:BYTE; lSize:Int32):Int32;stdcall;external'okapi32.dll';
                		//read audio captured from inner data buffer
                		//lpAudioBuf is your memory address to store
                		//lSize is data length (in byte) you expect to read
                		//return the data length (in byte) truelly read

//--6. stream section routines--------------

//-----defines wParam in okSetStreamParam


//prolog and epilog
function okOpenStream(hBoard:HWND; lParam:DWORD):HWND;stdcall;external'okapi32.dll';
                		//open stream device owned by the video capture board
                		//when b0 of lParam is 1 just check if this board support hardware compressing
                		//return handle of the stream device

function okCloseStream(hStream:HWND):Boolean;stdcall;external'okapi32.dll';
                		//close stream device

//capture and stop
function okCaptureStream(hStream:HWND; tgt:TARGET; lpfnUserProc:TFarProc; lParam:MLONG):HWND;stdcall;external'okapi32.dll';
                		//start to capture stream data, target can be NONE(0)/BUFFER(stream buffer), or file name
                		//lpfnUserProc is callback function pointer, it must be NULL if not using callback
                		//lMiliSeconds=0: forever capturing until stop by okStopCaptureStream;
                		// non 0: specified periods to capture in mili-second
                		//success if return non 0

function WriteStreamProc(hStream:HWND; var lpStreamBuf:BYTE; length:Int32):Boolean;stdcall;external'okapi32.dll';
                		//this callback function must written as the above protype by user
                		//call this function when there are enough stream data (the length in byte)
                		//lpStreamBuf is input pointer which points memory with stream data provided by system
                		//length is size of input stream data this call
                		//call this function when capture ended with argument length=0;

function okStopCaptureStream(hStream:HWND; dwCmdCode:DWORD):Boolean;stdcall;external'okapi32.dll';
                		//stop or pause/re-encode capturing stream data
                		//dwCmdCode=0: stop, dwCmdCode=1: pause, dwCmdCode:=2: re-encode
                		//return total length of read out by okReadStreamData

//set and get stream
function okSetStreamParam(hStream:HWND; wParam:Int32; lParam:MLONG):MLONG;stdcall;external'okapi32.dll';
                		//set the parameters to sample stream,  wParam see above defines
                		//return the new set value if success
                		//if not support return -1, if error return -2
                		//if input lParam=-1, just return previous param

function okReadStreamData(hStream:HWND; lpStreamBuf:LPBYTE; lReadSize:Int32):Int32;stdcall;external'okapi32.dll';
                		//read stream captured from inner data buffer
                		//lpStreamBuf is your memory address to store
                		//lReadSize is data length (in byte) you expect to read
                		//return the data length (in byte) truelly read

function okGetCurrStream(hStream:HWND; lParam:Pointer):MLONG;stdcall;external'okapi32.dll';
                       		//get infos of current stream being coded by hardware
                       		//return number of frame coded



//--7. serial device embedded in board--------------
function okSetSerial(hBoard:HWND; wParam:Int32; lParam:Int32):Int32;stdcall;external'okapi32.dll';
                		//set serial device config parameter and return previous parameter;
                		//wParam is item to set, lParam is parameter value
                		//if input lParam=-1, just return previous parameter not to set
                		//if not support return -1, if error return -2

function okReadSerial(hBoard:HWND; lpBuffer:Pointer; lSize:Int32; lTimeOut:MLONG):Int32;stdcall;external'okapi32.dll';
                		//read data from current serial comm device
                		//lpBuffer is buffer to read, lSize is size of buffer
                		//return the size read actually

function okWriteSerial(hBoard:HWND; lpBuffer:Pointer; lSize:Int32; lTimeOut:MLONG):Boolean;stdcall;external'okapi32.dll';
                		//write data to current serial comm device
                		//lpBuffer is buffer stored data to write, lSize is data length to write
                		//return true if success

//--8. ports io utilities--------------
                	//this function only used for OK PCI GPIO20
function okGetGPIOPort(index:SHORT; var wPortBase:WORD):SHORT;stdcall;external'okapi32.dll';
                		//get port base and count of ok PCI GPIO20
                		//index is the nomber (0 based) of gpio cards,
                		//wPortBase: port base,  return port count if success else return 0

// for Non-PCI IO cards on WinNT/Win2000
// you must call this function before using follow port io functions
function okSetPortBase(wPortBase:WORD; iPortCount:SHORT):Boolean;stdcall;external'okapi32.dll';
                	//set ports to use by setting port base address and port count

//note: before call the follow i/o functions you should have called one of
//those functions: okOpenBoard, okGetGPIOPort, okGetImageDevice
function okOutputByte(wPort:WORD; data:BYTE):Boolean;stdcall;external'okapi32.dll';
                	//output a byte at specified port

function okOutputShort(wPort:WORD; data:SHORT):Boolean;stdcall;external'okapi32.dll';
                	//output a word at specified port

function okOutputLong(wPort:WORD; data:MLONG):Boolean;stdcall;external'okapi32.dll';
                	//output a dword at specified port

//----------- input data at port
function okInputByte(wPort:WORD):BYTE;stdcall;external'okapi32.dll';
                	//input a byte at specified port

function okInputShort(wPort:WORD):SHORT;stdcall;external'okapi32.dll';
                	//input a word at specified port

function okInputLong(wPort:WORD):MLONG;stdcall;external'okapi32.dll';
                	//input a dword at specified port

function okGetAddrForVB(value:Longint):MWORD;stdcall;external'okapi32.dll';
                		//return array address for VB

//-----------get time elapse
function okGetTickCount:DWORD;stdcall;external'okapi32.dll';
                	//same as GetTickCount but exactly than it on Win2k

procedure okSleep(dwMill:DWORD)stdcall;external'okapi32.dll';
                	//same as Sleep but exactly than it on Win2k

function okGetTickCountMicro(var lpHiDWord:DWORD):DWORD;stdcall;external'okapi32.dll';
                		//same as GetTickCount but exactly in Micro Second
                		//if lpHiDWord get high dword

procedure okSleepMicro(dwMicro:DWORD)stdcall;external'okapi32.dll';
                		//Sleep micro seconds
//-------------------end--------------------------



implementation

end.

