unit Signal;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  ExtCtrls, okapi32, Windows;

type

  { TSignalBox }

  TSignalBox = class(TForm)
    AutoSearch: TButton;
    btnOK: TButton;
    OkCamera: TCheckBox;
    RGP: TRadioGroup;
    SetVideo: TButton;
    AutoFineSet: TButton;
    procedure AutoFineSetClick(Sender: TObject);
    procedure AutoSearchClick(Sender: TObject);
    procedure btnOKClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure OkCameraClick(Sender: TObject);
    procedure SetVideoClick(Sender: TObject);
  private
    { private declarations }
    videotype,scanlines,fieldfrq:Integer;
    function exAutoSetVideoParams(vtype:Integer; slines:Integer; fieldfreq:Integer; sample43:Integer):Integer;
    function AutoSetChan(hBoard:HWND):Boolean;//autosetchan return=TRUE(exist)	FALSE(not exist)
    function IsInput(hBoard:HWND):Boolean;
  public
    { public declarations }
  end;

const
    CDEGREE = 5;
    DEGREELIMIT	= CDEGREE*0.8;
    MINFREQ = 10;
    MINLINE = 10;
    MAXDIFFFIELD = 3;
    MAXDIFFLINE	= 10;

var
  SignalBox: TSignalBox;
  lblSignal: Array [0..9] of TLabel;
  lCameraCode:Longint;		//OkCamera

implementation

uses
    main;

{$R *.lfm}

{ TSignalBox }

procedure TSignalBox.FormCreate(Sender: TObject);
var
    i:Integer;
begin
  lCameraCode := -1;

  for i:=Low(lblSignal) to High(lblSignal) do
  begin
      lblSignal[i]:=TLabel.Create(Self);
      lblSignal[i].Parent:=SignalBox;
      lblSignal[i].Left:=50+(i Div 5)*150;
      lblSignal[i].Top:=50+(i Mod 5)*30;
      lblSignal[i].Font.Size:=10;
  end;
  lblSignal[0].Caption:='视频输入源:';
  lblSignal[1].Caption:='视频输入类型:';
  lblSignal[2].Caption:='垂直扫描线数:';
  lblSignal[3].Caption:='帧频(每秒帧数):';
  lblSignal[4].Caption:='外触发状态:';
end;

procedure TSignalBox.btnOKClick(Sender: TObject);
begin
  FormShow(Sender);
end;

procedure TSignalBox.AutoFineSetClick(Sender: TObject);
begin
    //自动细调参数
    okAutoSetCapRect(hBoard,0,0); //full auto-fine-set
    exAllocateDIBMemory(hBoard); //may be re-new size
    Close;
end;

procedure TSignalBox.AutoSearchClick(Sender: TObject);
begin
     if (AutoSetChan(hBoard)) then
     begin
         Sleep(200);

 	 FormShow(Sender);
         AutoSearch.Enabled := FALSE;
     end;
end;

procedure TSignalBox.FormDestroy(Sender: TObject);
var
   i:Integer;
begin
  //窗口关闭
  for i:=Low(lblSignal) to High(lblSignal) do
      if Assigned(lblSignal[i]) then lblSignal[i].Free;
end;

procedure TSignalBox.FormShow(Sender: TObject);
var
    dlstr:String;
    extsign:Integer;
    videocolor:Integer;
    ret:Integer;
    szBoardName:Array[0..30] of char;
begin
    okGetTypeCode(hBoard, szBoardName);
    Caption := '当前视频输入信息' + '     (' + szBoardName + ')';

    AutoSearch.Enabled := TRUE;

    //video exist
    extsign := okGetSignalParam(hBoard, SIGNAL_VIDEOEXIST);
    case (extsign) of
    0:
        dlstr := '未检测到信号源';
    1:
        dlstr := '检测到信号源';
    -1:
        begin
            dlstr := '不支持';
            AutoSearch.Enabled := FALSE;
        end;
    end;

    if (extsign = 1) then
    begin
        videocolor := okGetSignalParam(hBoard, SIGNAL_VIDEOCOLOR);
        case (videocolor) of
        1:
            dlstr := dlstr + '(Color)';
        0:
            dlstr := dlstr + '(B/W)';
        end;
    end;

    lblSignal[5].Caption := dlstr;

    //video type
    if (extsign = 1) then
    begin
        okWaitSignalEvent(hBoard, EVENT_ODDFIELD, 40);
        videotype := okGetSignalParam(hBoard, SIGNAL_VIDEOTYPE);
        case (videotype) of
        0:
            dlstr := '逐行信号(Non-interlaced)';
        1:
            dlstr := '隔行信号(Interlaced)';
        -1:
            dlstr := '不支持';
        end;
    end
    else
        dlstr := '未知';
    lblSignal[6].Caption := dlstr;

    //video scanlines
    scanlines := -1;
    if (extsign = 1) then
    begin
        scanlines := okGetSignalParam(hBoard, SIGNAL_SCANLINES);
        if (scanlines > 0) then
            dlstr := IntToStr(scanlines) + ' 行数/幅'
        else
            if (scanlines = -1) then
                dlstr := '不支持';
    end
    else
        dlstr := '未知';
    lblSignal[7].Caption := dlstr;

    //video field frequency
    if (extsign = 1) then
    begin
        fieldfrq := okGetSignalParam(hBoard, SIGNAL_FIELDFREQ);
        if (fieldfrq = -1) then
            dlstr := '不支持'
        else
            dlstr := IntToStr(fieldfrq) + ' 场数/秒';
    end
    else
        if (extsign = -1) then
            dlstr := '未知';
    lblSignal[8].Caption := dlstr;

    //extern trigger
    ret := okGetSignalParam(hBoard, SIGNAL_EXTTRIGGER);
    case (ret) of
    -1:
        dlstr := '不支持';
    1:
        dlstr := '触发状态';
    else
        dlstr := '无触发状态';
    end;
    lblSignal[9].Caption := dlstr;

    RGP.ItemIndex := 0;
    RGP.Enabled := FALSE;
    //firstly assume that can not detect signal infos
    SetVideo.Enabled := FALSE;
    AutoFineSet.Enabled := FALSE;
    if (scanlines <> -1) then//can not detect signal infos
    begin
        SetVideo.Enabled := TRUE;
        AutoFineSet.Enabled := TRUE;
  		//if( okSetCaptureParam(hBoard,CAPTURE_HORZPIXELS,-1)!=-1 ) {
        RGP.Enabled := TRUE;
  		//}
    end;

    //test out trigger
    okPutSignalParam(hBoard,PUTSIGNAL_TRIGGER,$ff);

    //enable vert sync
    okPutSignalParam(hBoard,PUTSIGNAL_VERTSYNC,1);
end;

procedure TSignalBox.OkCameraClick(Sender: TObject);
var
    szCameraName:String;
//				HANDLE hCamera;
				//char szPortName[10]="COM";
			 	//char szCameraName[10];
//				HCURSOR	hArrow = LoadCursor(NULL, IDC_ARROW);
//				HCURSOR	hAppStart = LoadCursor(NULL, IDC_APPSTARTING );
begin
    //SetCursor(hAppStart);
    //hCamera=okCamOpenCamera(&lCameraCode,szPortName);
    //SetCursor(hArrow);

    case (lCameraCode) of
    201100:
        szCameraName := 'AM1100';
    201101:
  	szCameraName := 'AM1101';
    //				case 201102:
    //					sprintf(szCameraName,"AM1100GX");
    //					break;
    //				case 201103:
    //					sprintf(szCameraName,"AM1101GX");
    //					break;
    201300:
  	szCameraName := 'AM1300';
    211200:
  	szCameraName := 'AC1200';
    211300:
  	szCameraName := 'AC1300';
    else
        begin
  	    lCameraCode := -1;
  	    //sprintf(szCameraName,"OK Camera?");
  	    OkCamera.Enabled := FALSE;
        end;
    end;
    if(lCameraCode>0) then
        Caption := szCameraName;

end;

procedure TSignalBox.SetVideoClick(Sender: TObject);
begin
    //自动设置采集参数
    if(Not OkCamera.Checked  ) then
    	lCameraCode := -1;	//OkCamera

    exAutoSetVideoParams(videotype, scanlines, fieldfrq, RGP.ItemIndex);

    exAllocateDIBMemory(hBoard); //may be re-new size

    //disable vert sync
    okPutSignalParam(hBoard,PUTSIGNAL_VERTSYNC,0);
    Close;
end;

function TSignalBox.exAutoSetVideoParams(vtype:Integer; slines:Integer; fieldfreq:Integer; sample43:Integer):Integer;
var
   tvstandard:Longint;
   samppixel,sampfreq,videoshift:Longint;
   dlrect:TRect;
   label re_calc;
begin
     //1.video type, 2. sample mode as video type
     okSetVideoParam(hBoard,VIDEO_SIGNALTYPE,vtype);
     okSetCaptureParam(hBoard,CAPTURE_SAMPLEFIELD,vtype); //0: field 1: frame

     //3.video standard 4.hp and vl, 5.frq segment
     //6 vidoe shift 7, sample rect
     //4:3
     if( (slines=625) and (vtype=1) ) then //interlace
     begin
          if(sample43=0) then //4:3
          begin
               tvstandard:=0; //PAL
               okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);
               okSetVideoParam(hBoard,VIDEO_FREQSEG,0); //lo seg
               SetRect(dlrect,0,0,768,576);
          end
          else  //1:1
          begin
               //first do vidoe rect shift
               videoshift:=MAKELONG( 100, HIWORD(okSetVideoParam(hBoard,VIDEO_RECTSHIFT,-1)) );
               okSetVideoParam(hBoard,VIDEO_RECTSHIFT,videoshift);

               tvstandard:=2; //non-standard
               okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);
               okSetVideoParam(hBoard,VIDEO_FREQSEG,0); //lo seg
               okSetCaptureParam(hBoard,CAPTURE_HORZPIXELS,709);
               okSetCaptureParam(hBoard,CAPTURE_VERTLINES,625);
               SetRect(dlrect,0,0,576,576);
          end;
     end
     else
     if((sample43=0) and (slines=525) and (vtype=1) ) then
     begin
          if(sample43=0) then //4:3
          begin
               tvstandard:=1; //NTSC
               okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);
               okSetVideoParam(hBoard,VIDEO_FREQSEG,0); //lo seg
               SetRect(dlrect,0,0,640,480);
          end
          else  //1:1
          begin
               //first do vidoe rect shift
               videoshift:=MAKELONG(70, HIWORD(okSetVideoParam(hBoard,VIDEO_RECTSHIFT,-1)) );
               okSetVideoParam(hBoard,VIDEO_RECTSHIFT,videoshift);

               tvstandard:=2; //non-standard
               okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);
               okSetVideoParam(hBoard,VIDEO_FREQSEG,0); //lo seg
               okSetCaptureParam(hBoard,CAPTURE_HORZPIXELS,591);
               okSetCaptureParam(hBoard,CAPTURE_VERTLINES,525);
               SetRect(dlrect,0,0,480,480);
          end;
     end
     else
     begin
          tvstandard:=2;//non-standard
          okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);

          if (sample43=0) then
             samppixel:=Round(slines*1.5104) //1.0 sample in 4:3
          else
              samppixel:=Round(slines*1.1328); //0.76 sample in 1:1
re_calc:
	  sampfreq:=Round(slines*samppixel/1000*fieldfreq/1000); //to unit MHz
          if(vtype=1) then//interlaced
              sampfreq:= sampfreq Div 2;

          if(sampfreq<14.75) then
	      sampfreq:=0 //low
          else if(sampfreq<30) then
               sampfreq:=1 //middle
          else if(sampfreq<=60) then
               sampfreq:=2 //high
          else
          begin
               samppixel:=Round(60000000/(slines*(fieldfreq shr vtype))); //
               goto re_calc;
          end;

          okSetCaptureParam(hBoard,CAPTURE_HORZPIXELS,samppixel);
          okSetCaptureParam(hBoard,CAPTURE_VERTLINES,slines);
          okSetVideoParam(hBoard,VIDEO_FREQSEG,sampfreq);

          //vidoe rect shift
          //videoshift=MAKELONG( (short)(samppixel*0.165),(short)(samppixel*0.0512));
          videoshift:=MAKELONG( Round(samppixel*0.18),Round(slines*0.08));
          okSetVideoParam(hBoard,VIDEO_RECTSHIFT,videoshift);
          //do again after set shift
          okSetVideoParam(hBoard,VIDEO_TVSTANDARD,tvstandard);

          SetRect(dlrect,0,0,Round(samppixel*0.8),Round(slines*0.9));
     end;
     okSetTargetRect(hBoard,DLVIDEO,dlrect);
     okSetTargetRect(hBoard,DLBUFFER,dlrect);

     Result:=tvstandard;
end;

function TSignalBox.AutoSetChan(hBoard:HWND):Boolean;
var
    boardtype:Longint;
    source:Longint;
    sync,sign:Shortint;
    syncsign:Longint;
    totalsource:Integer;

    videocolor:Integer;
begin
    boardtype := okGetTypeCode(hBoard, nil);
    if ((boardtype<3000) or (boardtype>4000 )) then //&& boardtype<5000))			//OK_M C	video
    begin
        if (boardtype>2000)	then	//Color Y/C
	begin
	    totalsource := $100+okSetVideoParam(hBoard, VIDEO_SOURCECHAN, $1ff);
	    for source := $100 to totalsource-1 do
	    begin
	        okSetVideoParam(hBoard,VIDEO_SOURCECHAN,source);
		Sleep(500);
		if (IsInput(hBoard)) then
		begin
		    videocolor := -1;
		    videocolor := okGetSignalParam(hBoard,SIGNAL_VIDEOCOLOR);

		    if (videocolor = 1)	then //Color
		    begin
		        Result := TRUE;
                        Exit;
		    end;
		end;
	    end;
	end;

//		okSetVideoParam(hBoard,VIDEO_SOURCECHAN,0);
//		Sleep(300);
		//Mono || Color  Video
        totalsource := okSetVideoParam(hBoard,VIDEO_SOURCECHAN,$0ff);
	for source:=0 to totalsource-1 do
	begin
	    okSetVideoParam(hBoard,VIDEO_SOURCECHAN,source);
	    Sleep(500);
	    if (IsInput(hBoard)) then
	    begin
	        Result := TRUE;
                Exit;
	    end;
        end;
    end

    else //if(boardtype<4000)		//OK_RGB
    begin
        totalsource := $200+okSetVideoParam(hBoard,VIDEO_SOURCECHAN,$2ff);
	for source:=$200 to totalsource-1 do			//RGB
	begin
            if (okSetVideoParam(hBoard,VIDEO_SOURCECHAN,source)<>-1) then
	    begin
	        for sign:=0 to 1 do
		begin
		    for sync:=0 to 4 do
		    begin
		        syncsign := MAKELONG(sync,sign);
			okSetVideoParam(hBoard,VIDEO_SYNCSIGCHAN,syncsign);

			Sleep(200);
			if(IsInput(hBoard)) then
			begin

                            if ((sync=0) or (sync=2)) then
			    begin
			        okSetVideoParam(hBoard,VIDEO_SOURCECHAN,sync+sign*3);
			    end;
			    Result := TRUE;
                            Exit;
			end;
		    end;
		end;
	    end;
	end;
    end;

    Result := FALSE;
end;

function TSignalBox.IsInput(hBoard:HWND):Boolean;
var
    scanline:Array [0..CDEGREE] of Integer;
    averline:Integer;
    i:Integer;
    count1,count2:Integer;
    diffline:Integer;
begin
    for i:=0 to CDEGREE do
        scanline[i] := 0;

    count1 :=0;
    for i:=0 to CDEGREE-1 do
    begin
        if (okGetSignalParam(hBoard,SIGNAL_VIDEOEXIST)=1) then
	      Inc(count1);

	if (count1>DEGREELIMIT) then
	      break;
    end;

    if (count1>DEGREELIMIT) then
    begin
        averline := 0;
	for i:=0 to CDEGREE-1 do //for(i=0,averfield=0,averline=0;i<DEGREE;i++)
	begin
	    Sleep(40);
//			fieldfrq[i]=okGetSignalParam(hBoard,SIGNAL_FIELDFREQ);
//			averfield+=fieldfrq[i];
            scanline[i]:= okGetSignalParam(hBoard,SIGNAL_SCANLINES);
	    averline := averline + scanline[i];
        end;
//		averfield=averfield/DEGREE;
        averline := averline div CDEGREE;

	if (averline>MINLINE) then//if(averfield>MINFREQ && averline>MINLINE)
	begin
                count2 := 0;
		for i:=0 to CDEGREE-1 do
		begin
//				int difffield;

//				difffield=fieldfrq[i]-averfield;
				        diffline := scanline[i]-averline;
				        if (Abs(diffline)<MAXDIFFLINE) then//if(fabs(difffield)<MAXDIFFFIELD && fabs(diffline)<MAXDIFFLINE)
                    Inc(count2);
                end;

	    if (count2>DEGREELIMIT) then
            begin
	        Result := TRUE;
                Exit;
            end
	    else
            begin
                Result := FALSE;
                Exit;
            end;

        end
	else
            if (averline=-1) then
            begin
	        Result := TRUE;
                Exit;
            end
	    else
            begin
	        Result := FALSE;
                Exit;
            end;
    end
    else
    begin
        Result := FALSE;
        Exit;
    end;
end;

end.

